# system configuration generated and used by the relenv at runtime
_build_time_vars = {'ABIFLAGS': '',
 'ABI_THREAD': '',
 'AC_APPLE_UNIVERSAL_BUILD': 0,
 'AIX_BUILDDATE': 0,
 'AIX_GENUINE_CPLUSPLUS': 0,
 'ALIGNOF_LONG': 8,
 'ALIGNOF_MAX_ALIGN_T': 16,
 'ALIGNOF_SIZE_T': 8,
 'ALT_SOABI': 0,
 'ANDROID_API_LEVEL': 0,
 'APP_STORE_COMPLIANCE_PATCH': '',
 'AR': 'x86_64-linux-gnu-ar',
 'ARFLAGS': 'rcs',
 'BASECFLAGS': '-fno-strict-overflow -Wsign-compare',
 'BASECPPFLAGS': '',
 'BASEMODLIBS': '',
 'BINDIR': '{BUILDROOT}/bin',
 'BINLIBDEST': '{BUILDROOT}/lib/python3.14',
 'BLDLIBRARY': 'libpython3.14.a',
 'BLDSHARED': '{TOOLCHAIN}/bin/x86_64-linux-gnu-gcc -pthread -shared '
              '-Wl,--build-id=sha1 -Wl,--rpath={BUILDROOT}/lib '
              '-L{BUILDROOT}/lib -L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib',
 'BOOTSTRAP_HEADERS': '\\',
 'BUILDEXE': '',
 'BUILDPYTHON': 'python',
 'BUILD_GNU_TYPE': 'x86_64-pc-linux-gnu',
 'BUILD_SCRIPTS_DIR': 'build/scripts-3.14',
 'BYTESTR_DEPS': '\\',
 'CC': '{TOOLCHAIN}/bin/x86_64-linux-gnu-gcc -pthread',
 'CCSHARED': '-fPIC',
 'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall '
           '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
           '-I{BUILDROOT}/include/readline -I{BUILDROOT}/include/ncursesw '
           '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include',
 'CFLAGSFORSHARED': '',
 'CFLAGS_ALIASING': '-fno-strict-aliasing',
 'CFLAGS_CEVAL': '',
 'CODECS_COMMON_HEADERS': './Modules/cjkcodecs/multibytecodec.h '
                          './Modules/cjkcodecs/cjkcodecs.h',
 'COMPILEALL_OPTS': '-j0',
 'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                'Makefile.pre.in',
 'CONFIGURE_CFLAGS': '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
                     '-I{BUILDROOT}/include/readline '
                     '-I{BUILDROOT}/include/ncursesw '
                     '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include',
 'CONFIGURE_CFLAGS_NODIST': '-fno-semantic-interposition -std=c11 -Wextra '
                            '-Wno-unused-parameter '
                            '-Wno-missing-field-initializers '
                            '-Wstrict-prototypes -fvisibility=hidden',
 'CONFIGURE_CPPFLAGS': '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
                       '-I{BUILDROOT}/include/ncursesw '
                       '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include',
 'CONFIGURE_LDFLAGS': '-Wl,--build-id=sha1 -Wl,--rpath={BUILDROOT}/lib '
                      '-L{BUILDROOT}/lib '
                      '-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib',
 'CONFIGURE_LDFLAGS_NODIST': '-fno-semantic-interposition',
 'CONFIGURE_LDFLAGS_NOLTO': '',
 'CONFIG_ARGS': "'-v' '--prefix={BUILDROOT}' '--with-openssl={BUILDROOT}' "
                "'--enable-optimizations' '--with-ensurepip=no' "
                "'--build=x86_64-linux-gnu' '--host=x86_64-linux-gnu' "
                "'--disable-test-modules' '--with-ssl-default-suites=openssl' "
                "'--with-builtin-hashlib-hashes=blake2,md5,sha1,sha2,sha3' "
                "'--with-readline=readline' '--with-pkg-config=yes' "
                "'--with-zstd=yes' 'ac_cv_file__dev_ptmx=yes' "
                "'ac_cv_file__dev_ptc=no' 'build_alias=x86_64-linux-gnu' "
                "'host_alias=x86_64-linux-gnu' "
                "'PKG_CONFIG_PATH={BUILDROOT}/lib/pkgconfig' "
                "'CC={TOOLCHAIN}/bin/x86_64-linux-gnu-gcc' "
                "'CFLAGS=-Wno-coverage-mismatch -g -I{BUILDROOT}/include "
                '-I{BUILDROOT}/include/readline -I{BUILDROOT}/include/ncursesw '
                "-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include' "
                "'LDFLAGS=-Wl,--build-id=sha1 -Wl,--rpath={BUILDROOT}/lib "
                "-L{BUILDROOT}/lib -L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib' "
                "'CPPFLAGS=-I{BUILDROOT}/include "
                '-I{BUILDROOT}/include/readline -I{BUILDROOT}/include/ncursesw '
                "-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include' "
                "'CURSES_LIBS=-lncursesw -ltinfow' 'PANEL_LIBS=-lpanelw'",
 'CONFINCLUDEDIR': '{BUILDROOT}/include',
 'CONFINCLUDEPY': '{BUILDROOT}/include/python3.14',
 'COREPYTHONPATH': '',
 'COVERAGE_INFO': '/home/runner/work/relenv/relenv/src/Python-3.14.5/coverage.info',
 'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
 'COVERAGE_REPORT': '/home/runner/work/relenv/relenv/src/Python-3.14.5/lcov-report',
 'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                            '--title "CPython 3.14 LCOV report [commit $(shell '
                            ')]"',
 'CPPFLAGS': '-I. -I./Include -I{BUILDROOT}/include '
             '-I{BUILDROOT}/include/readline -I{BUILDROOT}/include/ncursesw '
             '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include',
 'CXX': '{TOOLCHAIN}/bin/x86_64-linux-gnu-g++ -pthread',
 'DESTDIRS': '{BUILDROOT} {BUILDROOT}/lib {BUILDROOT}/lib/python3.14 '
             '{BUILDROOT}/lib/python3.14/lib-dynload',
 'DESTLIB': '{BUILDROOT}/lib/python3.14',
 'DESTPATH': '',
 'DESTSHARED': '{BUILDROOT}/lib/python3.14/lib-dynload',
 'DFLAGS': '',
 'DIRMODE': 755,
 'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
         'Makefile.pre.in Include Lib Misc Ext-dummy',
 'DISTDIRS': 'Include Lib Misc Ext-dummy',
 'DISTFILES': 'README.rst ChangeLog configure configure.ac acconfig.h '
              'pyconfig.h.in Makefile.pre.in',
 'DLINCLDIR': '.',
 'DLLLIBRARY': '',
 'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
 'DSYMUTIL': '',
 'DSYMUTIL_PATH': '',
 'DTRACE': '',
 'DTRACE_DEPS': '\\',
 'DTRACE_HEADERS': '',
 'DTRACE_OBJS': '',
 'DYNLOADFILE': 'dynload_shlib.o',
 'EMSCRIPTEN_DIR': './Platforms/emscripten',
 'ENABLE_IPV6': 1,
 'ENSUREPIP': 'no',
 'EXE': '',
 'EXEMODE': 755,
 'EXENAME': '{BUILDROOT}/bin/python3.14',
 'EXPORTSFROM': '',
 'EXPORTSYMS': '',
 'EXTRATESTOPTS': '',
 'EXTRA_CFLAGS': '',
 'EXT_SUFFIX': '.cpython-314-x86_64-linux-gnu.so',
 'FILEMODE': 644,
 'FREEZE_MODULE': './_bootstrap_python ./Programs/_freeze_module.py',
 'FREEZE_MODULE_BOOTSTRAP': './Programs/_freeze_module',
 'FREEZE_MODULE_BOOTSTRAP_DEPS': 'Programs/_freeze_module',
 'FREEZE_MODULE_DEPS': '_bootstrap_python ./Programs/_freeze_module.py',
 'FROZEN_FILES_IN': '\\',
 'FROZEN_FILES_OUT': '\\',
 'GETPGRP_HAVE_ARG': 0,
 'GITBRANCH': '',
 'GITTAG': '',
 'GITVERSION': '',
 'GNULD': 'yes',
 'HAVE_ACCEPT': 1,
 'HAVE_ACCEPT4': 1,
 'HAVE_ACOSH': 1,
 'HAVE_ADDRINFO': 1,
 'HAVE_ALARM': 1,
 'HAVE_ALIGNED_REQUIRED': 0,
 'HAVE_ALLOCA_H': 1,
 'HAVE_ALTZONE': 0,
 'HAVE_ASINH': 1,
 'HAVE_ASM_TYPES_H': 1,
 'HAVE_ATANH': 1,
 'HAVE_BACKTRACE': 1,
 'HAVE_BIND': 1,
 'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
 'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
 'HAVE_BLUETOOTH_H': 0,
 'HAVE_BROKEN_MBSTOWCS': 0,
 'HAVE_BROKEN_NICE': 0,
 'HAVE_BROKEN_PIPE_BUF': 0,
 'HAVE_BROKEN_POLL': 0,
 'HAVE_BROKEN_POSIX_SEMAPHORES': 0,
 'HAVE_BROKEN_PTHREAD_SIGMASK': 0,
 'HAVE_BROKEN_SEM_GETVALUE': 0,
 'HAVE_BROKEN_UNSETENV': 0,
 'HAVE_BUILTIN_ATOMIC': 1,
 'HAVE_BZLIB_H': 1,
 'HAVE_CHFLAGS': 0,
 'HAVE_CHMOD': 1,
 'HAVE_CHOWN': 1,
 'HAVE_CHROOT': 1,
 'HAVE_CLOCK': 1,
 'HAVE_CLOCK_GETRES': 1,
 'HAVE_CLOCK_GETTIME': 1,
 'HAVE_CLOCK_NANOSLEEP': 1,
 'HAVE_CLOCK_SETTIME': 1,
 'HAVE_CLOCK_T': 1,
 'HAVE_CLOSEFROM': 0,
 'HAVE_CLOSE_RANGE': 0,
 'HAVE_COMPUTED_GOTOS': 1,
 'HAVE_CONFSTR': 1,
 'HAVE_CONIO_H': 0,
 'HAVE_CONNECT': 1,
 'HAVE_COPY_FILE_RANGE': 0,
 'HAVE_CTERMID': 1,
 'HAVE_CTERMID_R': 0,
 'HAVE_CURSES_FILTER': 1,
 'HAVE_CURSES_H': 1,
 'HAVE_CURSES_HAS_KEY': 1,
 'HAVE_CURSES_IMMEDOK': 1,
 'HAVE_CURSES_IS_PAD': 1,
 'HAVE_CURSES_IS_TERM_RESIZED': 1,
 'HAVE_CURSES_RESIZETERM': 1,
 'HAVE_CURSES_RESIZE_TERM': 1,
 'HAVE_CURSES_SYNCOK': 1,
 'HAVE_CURSES_TYPEAHEAD': 1,
 'HAVE_CURSES_USE_ENV': 1,
 'HAVE_CURSES_WCHGAT': 1,
 'HAVE_DB_H': 0,
 'HAVE_DECL_RTLD_DEEPBIND': 1,
 'HAVE_DECL_RTLD_GLOBAL': 1,
 'HAVE_DECL_RTLD_LAZY': 1,
 'HAVE_DECL_RTLD_LOCAL': 1,
 'HAVE_DECL_RTLD_MEMBER': 0,
 'HAVE_DECL_RTLD_NODELETE': 1,
 'HAVE_DECL_RTLD_NOLOAD': 1,
 'HAVE_DECL_RTLD_NOW': 1,
 'HAVE_DECL_TZNAME': 0,
 'HAVE_DECL_UT_NAMESIZE': 1,
 'HAVE_DEVICE_MACROS': 1,
 'HAVE_DEV_PTC': 0,
 'HAVE_DEV_PTMX': 1,
 'HAVE_DIRECT_H': 0,
 'HAVE_DIRENT_D_TYPE': 1,
 'HAVE_DIRENT_H': 1,
 'HAVE_DIRFD': 1,
 'HAVE_DLADDR': 1,
 'HAVE_DLADDR1': 1,
 'HAVE_DLFCN_H': 1,
 'HAVE_DLOPEN': 1,
 'HAVE_DUP': 1,
 'HAVE_DUP2': 1,
 'HAVE_DUP3': 1,
 'HAVE_DYLD_SHARED_CACHE_CONTAINS_PATH': 0,
 'HAVE_DYNAMIC_LOADING': 1,
 'HAVE_EDITLINE_READLINE_H': 0,
 'HAVE_ENDIAN_H': 1,
 'HAVE_EPOLL': 1,
 'HAVE_EPOLL_CREATE1': 1,
 'HAVE_ERF': 1,
 'HAVE_ERFC': 1,
 'HAVE_ERRNO_H': 1,
 'HAVE_EVENTFD': 1,
 'HAVE_EXECINFO_H': 1,
 'HAVE_EXECV': 1,
 'HAVE_EXPLICIT_BZERO': 0,
 'HAVE_EXPLICIT_MEMSET': 0,
 'HAVE_EXPM1': 1,
 'HAVE_FACCESSAT': 1,
 'HAVE_FCHDIR': 1,
 'HAVE_FCHMOD': 1,
 'HAVE_FCHMODAT': 1,
 'HAVE_FCHOWN': 1,
 'HAVE_FCHOWNAT': 1,
 'HAVE_FCNTL_H': 1,
 'HAVE_FDATASYNC': 1,
 'HAVE_FDOPENDIR': 1,
 'HAVE_FDWALK': 0,
 'HAVE_FEXECVE': 1,
 'HAVE_FFI_CLOSURE_ALLOC': 1,
 'HAVE_FFI_PREP_CIF_VAR': 1,
 'HAVE_FFI_PREP_CLOSURE_LOC': 1,
 'HAVE_FLOCK': 1,
 'HAVE_FORK': 1,
 'HAVE_FORK1': 0,
 'HAVE_FORKPTY': 1,
 'HAVE_FPATHCONF': 1,
 'HAVE_FSEEK64': 0,
 'HAVE_FSEEKO': 1,
 'HAVE_FSTATAT': 1,
 'HAVE_FSTATVFS': 1,
 'HAVE_FSYNC': 1,
 'HAVE_FTELL64': 0,
 'HAVE_FTELLO': 1,
 'HAVE_FTIME': 1,
 'HAVE_FTRUNCATE': 1,
 'HAVE_FUTIMENS': 1,
 'HAVE_FUTIMES': 1,
 'HAVE_FUTIMESAT': 1,
 'HAVE_GAI_STRERROR': 1,
 'HAVE_GCC_ASM_FOR_MC68881': 0,
 'HAVE_GCC_ASM_FOR_X64': 1,
 'HAVE_GCC_ASM_FOR_X87': 1,
 'HAVE_GCC_UINT128_T': 1,
 'HAVE_GDBM_DASH_NDBM_H': 0,
 'HAVE_GDBM_H': 1,
 'HAVE_GDBM_NDBM_H': 0,
 'HAVE_GETADDRINFO': 1,
 'HAVE_GETC_UNLOCKED': 1,
 'HAVE_GETEGID': 1,
 'HAVE_GETENTROPY': 0,
 'HAVE_GETEUID': 1,
 'HAVE_GETGID': 1,
 'HAVE_GETGRENT': 1,
 'HAVE_GETGRGID': 1,
 'HAVE_GETGRGID_R': 1,
 'HAVE_GETGRNAM_R': 1,
 'HAVE_GETGROUPLIST': 1,
 'HAVE_GETGROUPS': 1,
 'HAVE_GETHOSTBYADDR': 1,
 'HAVE_GETHOSTBYNAME': 1,
 'HAVE_GETHOSTBYNAME_R': 1,
 'HAVE_GETHOSTBYNAME_R_3_ARG': 0,
 'HAVE_GETHOSTBYNAME_R_5_ARG': 0,
 'HAVE_GETHOSTBYNAME_R_6_ARG': 1,
 'HAVE_GETHOSTNAME': 1,
 'HAVE_GETITIMER': 1,
 'HAVE_GETLOADAVG': 1,
 'HAVE_GETLOGIN': 1,
 'HAVE_GETLOGIN_R': 1,
 'HAVE_GETNAMEINFO': 1,
 'HAVE_GETPAGESIZE': 1,
 'HAVE_GETPEERNAME': 1,
 'HAVE_GETPGID': 1,
 'HAVE_GETPGRP': 1,
 'HAVE_GETPID': 1,
 'HAVE_GETPPID': 1,
 'HAVE_GETPRIORITY': 1,
 'HAVE_GETPROTOBYNAME': 1,
 'HAVE_GETPWENT': 1,
 'HAVE_GETPWNAM_R': 1,
 'HAVE_GETPWUID': 1,
 'HAVE_GETPWUID_R': 1,
 'HAVE_GETRANDOM': 0,
 'HAVE_GETRANDOM_SYSCALL': 1,
 'HAVE_GETRESGID': 1,
 'HAVE_GETRESUID': 1,
 'HAVE_GETRUSAGE': 1,
 'HAVE_GETSERVBYNAME': 1,
 'HAVE_GETSERVBYPORT': 1,
 'HAVE_GETSID': 1,
 'HAVE_GETSOCKNAME': 1,
 'HAVE_GETSPENT': 1,
 'HAVE_GETSPNAM': 1,
 'HAVE_GETUID': 1,
 'HAVE_GETWD': 1,
 'HAVE_GLIBC_MEMMOVE_BUG': 0,
 'HAVE_GRANTPT': 1,
 'HAVE_GRP_H': 1,
 'HAVE_HSTRERROR': 1,
 'HAVE_HTOLE64': 1,
 'HAVE_IF_NAMEINDEX': 1,
 'HAVE_INET_ATON': 1,
 'HAVE_INET_NTOA': 1,
 'HAVE_INET_PTON': 1,
 'HAVE_INITGROUPS': 1,
 'HAVE_INTTYPES_H': 1,
 'HAVE_IO_H': 0,
 'HAVE_IPA_PURE_CONST_BUG': 0,
 'HAVE_KILL': 1,
 'HAVE_KILLPG': 1,
 'HAVE_KQUEUE': 0,
 'HAVE_LANGINFO_H': 1,
 'HAVE_LARGEFILE_SUPPORT': 0,
 'HAVE_LCHFLAGS': 0,
 'HAVE_LCHMOD': 0,
 'HAVE_LCHOWN': 1,
 'HAVE_LIBDB': 0,
 'HAVE_LIBDL': 1,
 'HAVE_LIBDLD': 0,
 'HAVE_LIBIEEE': 0,
 'HAVE_LIBINTL_H': 1,
 'HAVE_LIBSENDFILE': 0,
 'HAVE_LIBSQLITE3': 1,
 'HAVE_LIBUTIL_H': 0,
 'HAVE_LINK': 1,
 'HAVE_LINKAT': 1,
 'HAVE_LINK_H': 1,
 'HAVE_LINUX_AUXVEC_H': 1,
 'HAVE_LINUX_CAN_BCM_H': 1,
 'HAVE_LINUX_CAN_H': 1,
 'HAVE_LINUX_CAN_J1939_H': 1,
 'HAVE_LINUX_CAN_RAW_FD_FRAMES': 1,
 'HAVE_LINUX_CAN_RAW_H': 1,
 'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 1,
 'HAVE_LINUX_FS_H': 1,
 'HAVE_LINUX_LIMITS_H': 1,
 'HAVE_LINUX_MEMFD_H': 1,
 'HAVE_LINUX_NETFILTER_IPV4_H': 1,
 'HAVE_LINUX_NETLINK_H': 1,
 'HAVE_LINUX_QRTR_H': 1,
 'HAVE_LINUX_RANDOM_H': 1,
 'HAVE_LINUX_SCHED_H': 1,
 'HAVE_LINUX_SOUNDCARD_H': 1,
 'HAVE_LINUX_TIPC_H': 1,
 'HAVE_LINUX_VM_SOCKETS_H': 1,
 'HAVE_LINUX_WAIT_H': 1,
 'HAVE_LISTEN': 1,
 'HAVE_LOCKF': 1,
 'HAVE_LOG1P': 1,
 'HAVE_LOG2': 1,
 'HAVE_LOGIN_TTY': 1,
 'HAVE_LONG_DOUBLE': 1,
 'HAVE_LSTAT': 1,
 'HAVE_LUTIMES': 1,
 'HAVE_LZMA_H': 0,
 'HAVE_MADVISE': 1,
 'HAVE_MAKEDEV': 1,
 'HAVE_MAXLOGNAME': 0,
 'HAVE_MBRTOWC': 1,
 'HAVE_MEMFD_CREATE': 0,
 'HAVE_MEMRCHR': 1,
 'HAVE_MINIX_CONFIG_H': 0,
 'HAVE_MKDIRAT': 1,
 'HAVE_MKFIFO': 1,
 'HAVE_MKFIFOAT': 1,
 'HAVE_MKNOD': 1,
 'HAVE_MKNODAT': 1,
 'HAVE_MKTIME': 1,
 'HAVE_MMAP': 1,
 'HAVE_MREMAP': 1,
 'HAVE_NANOSLEEP': 1,
 'HAVE_NCURSES': 0,
 'HAVE_NCURSESW': 1,
 'HAVE_NCURSESW_CURSES_H': 1,
 'HAVE_NCURSESW_NCURSES_H': 1,
 'HAVE_NCURSESW_PANEL_H': 1,
 'HAVE_NCURSES_CURSES_H': 0,
 'HAVE_NCURSES_H': 1,
 'HAVE_NCURSES_NCURSES_H': 0,
 'HAVE_NCURSES_PANEL_H': 0,
 'HAVE_NDBM_H': 1,
 'HAVE_NDIR_H': 0,
 'HAVE_NETCAN_CAN_H': 0,
 'HAVE_NETDB_H': 1,
 'HAVE_NETINET_IN_H': 1,
 'HAVE_NETLINK_NETLINK_H': 0,
 'HAVE_NETPACKET_PACKET_H': 1,
 'HAVE_NET_ETHERNET_H': 1,
 'HAVE_NET_IF_H': 1,
 'HAVE_NICE': 1,
 'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
 'HAVE_OPENAT': 1,
 'HAVE_OPENDIR': 1,
 'HAVE_OPENPTY': 1,
 'HAVE_PANEL': 0,
 'HAVE_PANELW': 1,
 'HAVE_PANEL_H': 1,
 'HAVE_PATHCONF': 1,
 'HAVE_PAUSE': 1,
 'HAVE_PIPE': 1,
 'HAVE_PIPE2': 1,
 'HAVE_PLOCK': 0,
 'HAVE_POLL': 1,
 'HAVE_POLL_H': 1,
 'HAVE_POSIX_FADVISE': 1,
 'HAVE_POSIX_FALLOCATE': 1,
 'HAVE_POSIX_OPENPT': 1,
 'HAVE_POSIX_SPAWN': 1,
 'HAVE_POSIX_SPAWNP': 1,
 'HAVE_POSIX_SPAWN_FILE_ACTIONS_ADDCLOSEFROM_NP': 0,
 'HAVE_PREAD': 1,
 'HAVE_PREADV': 1,
 'HAVE_PREADV2': 0,
 'HAVE_PRLIMIT': 1,
 'HAVE_PROCESS_H': 0,
 'HAVE_PROCESS_VM_READV': 1,
 'HAVE_PROTOTYPES': 1,
 'HAVE_PTHREAD_CONDATTR_SETCLOCK': 1,
 'HAVE_PTHREAD_COND_TIMEDWAIT_RELATIVE_NP': 0,
 'HAVE_PTHREAD_DESTRUCTOR': 0,
 'HAVE_PTHREAD_GETATTR_NP': 1,
 'HAVE_PTHREAD_GETCPUCLOCKID': 1,
 'HAVE_PTHREAD_GETNAME_NP': 1,
 'HAVE_PTHREAD_GET_NAME_NP': 0,
 'HAVE_PTHREAD_H': 1,
 'HAVE_PTHREAD_INIT': 0,
 'HAVE_PTHREAD_KILL': 1,
 'HAVE_PTHREAD_SETNAME_NP': 1,
 'HAVE_PTHREAD_SET_NAME_NP': 0,
 'HAVE_PTHREAD_SIGMASK': 1,
 'HAVE_PTHREAD_STUBS': 0,
 'HAVE_PTSNAME': 1,
 'HAVE_PTSNAME_R': 1,
 'HAVE_PTY_H': 1,
 'HAVE_PWRITE': 1,
 'HAVE_PWRITEV': 1,
 'HAVE_PWRITEV2': 0,
 'HAVE_READLINE_READLINE_H': 1,
 'HAVE_READLINK': 1,
 'HAVE_READLINKAT': 1,
 'HAVE_READV': 1,
 'HAVE_REALPATH': 1,
 'HAVE_RECVFROM': 1,
 'HAVE_RENAMEAT': 1,
 'HAVE_RL_APPEND_HISTORY': 0,
 'HAVE_RL_CATCH_SIGNAL': 0,
 'HAVE_RL_COMPDISP_FUNC_T': 0,
 'HAVE_RL_COMPLETION_APPEND_CHARACTER': 0,
 'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 0,
 'HAVE_RL_COMPLETION_MATCHES': 0,
 'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 0,
 'HAVE_RL_PRE_INPUT_HOOK': 0,
 'HAVE_RL_RESIZE_TERMINAL': 0,
 'HAVE_RTPSPAWN': 0,
 'HAVE_SCHED_GET_PRIORITY_MAX': 1,
 'HAVE_SCHED_H': 1,
 'HAVE_SCHED_RR_GET_INTERVAL': 1,
 'HAVE_SCHED_SETAFFINITY': 1,
 'HAVE_SCHED_SETPARAM': 1,
 'HAVE_SCHED_SETSCHEDULER': 1,
 'HAVE_SEM_CLOCKWAIT': 0,
 'HAVE_SEM_GETVALUE': 1,
 'HAVE_SEM_OPEN': 1,
 'HAVE_SEM_TIMEDWAIT': 1,
 'HAVE_SEM_UNLINK': 1,
 'HAVE_SENDFILE': 1,
 'HAVE_SENDTO': 1,
 'HAVE_SETEGID': 1,
 'HAVE_SETEUID': 1,
 'HAVE_SETGID': 1,
 'HAVE_SETGROUPS': 1,
 'HAVE_SETHOSTNAME': 1,
 'HAVE_SETITIMER': 1,
 'HAVE_SETJMP_H': 1,
 'HAVE_SETLOCALE': 1,
 'HAVE_SETNS': 1,
 'HAVE_SETPGID': 1,
 'HAVE_SETPGRP': 1,
 'HAVE_SETPRIORITY': 1,
 'HAVE_SETREGID': 1,
 'HAVE_SETRESGID': 1,
 'HAVE_SETRESUID': 1,
 'HAVE_SETREUID': 1,
 'HAVE_SETSID': 1,
 'HAVE_SETSOCKOPT': 1,
 'HAVE_SETUID': 1,
 'HAVE_SETVBUF': 1,
 'HAVE_SHADOW_H': 1,
 'HAVE_SHM_OPEN': 1,
 'HAVE_SHM_UNLINK': 1,
 'HAVE_SHUTDOWN': 1,
 'HAVE_SIGACTION': 1,
 'HAVE_SIGALTSTACK': 1,
 'HAVE_SIGFILLSET': 1,
 'HAVE_SIGINFO_T_SI_BAND': 1,
 'HAVE_SIGINTERRUPT': 1,
 'HAVE_SIGNAL_H': 1,
 'HAVE_SIGPENDING': 1,
 'HAVE_SIGRELSE': 1,
 'HAVE_SIGTIMEDWAIT': 1,
 'HAVE_SIGWAIT': 1,
 'HAVE_SIGWAITINFO': 1,
 'HAVE_SNPRINTF': 1,
 'HAVE_SOCKADDR_ALG': 1,
 'HAVE_SOCKADDR_SA_LEN': 0,
 'HAVE_SOCKADDR_STORAGE': 1,
 'HAVE_SOCKET': 1,
 'HAVE_SOCKETPAIR': 1,
 'HAVE_SOCKLEN_T': 1,
 'HAVE_SPAWN_H': 1,
 'HAVE_SPLICE': 1,
 'HAVE_SSIZE_T': 1,
 'HAVE_STATVFS': 1,
 'HAVE_STAT_TV_NSEC': 1,
 'HAVE_STAT_TV_NSEC2': 0,
 'HAVE_STDINT_H': 1,
 'HAVE_STDIO_H': 1,
 'HAVE_STDLIB_H': 1,
 'HAVE_STD_ATOMIC': 1,
 'HAVE_STRFTIME': 1,
 'HAVE_STRINGS_H': 1,
 'HAVE_STRING_H': 1,
 'HAVE_STRLCPY': 0,
 'HAVE_STROPTS_H': 1,
 'HAVE_STRSIGNAL': 1,
 'HAVE_STRUCT_PASSWD_PW_GECOS': 1,
 'HAVE_STRUCT_PASSWD_PW_PASSWD': 1,
 'HAVE_STRUCT_STAT_ST_BIRTHTIME': 0,
 'HAVE_STRUCT_STAT_ST_BLKSIZE': 1,
 'HAVE_STRUCT_STAT_ST_BLOCKS': 1,
 'HAVE_STRUCT_STAT_ST_FLAGS': 0,
 'HAVE_STRUCT_STAT_ST_GEN': 0,
 'HAVE_STRUCT_STAT_ST_RDEV': 1,
 'HAVE_STRUCT_TM_TM_ZONE': 1,
 'HAVE_SYMLINK': 1,
 'HAVE_SYMLINKAT': 1,
 'HAVE_SYNC': 1,
 'HAVE_SYSCONF': 1,
 'HAVE_SYSEXITS_H': 1,
 'HAVE_SYSLOG_H': 1,
 'HAVE_SYSTEM': 1,
 'HAVE_SYS_AUDIOIO_H': 0,
 'HAVE_SYS_AUXV_H': 1,
 'HAVE_SYS_BSDTTY_H': 0,
 'HAVE_SYS_DEVPOLL_H': 0,
 'HAVE_SYS_DIR_H': 0,
 'HAVE_SYS_ENDIAN_H': 0,
 'HAVE_SYS_EPOLL_H': 1,
 'HAVE_SYS_EVENTFD_H': 1,
 'HAVE_SYS_EVENT_H': 0,
 'HAVE_SYS_FILE_H': 1,
 'HAVE_SYS_IOCTL_H': 1,
 'HAVE_SYS_KERN_CONTROL_H': 0,
 'HAVE_SYS_LOADAVG_H': 0,
 'HAVE_SYS_LOCK_H': 0,
 'HAVE_SYS_MEMFD_H': 0,
 'HAVE_SYS_MKDEV_H': 0,
 'HAVE_SYS_MMAN_H': 1,
 'HAVE_SYS_MODEM_H': 0,
 'HAVE_SYS_NDIR_H': 0,
 'HAVE_SYS_PARAM_H': 1,
 'HAVE_SYS_PIDFD_H': 0,
 'HAVE_SYS_POLL_H': 1,
 'HAVE_SYS_RANDOM_H': 0,
 'HAVE_SYS_RESOURCE_H': 1,
 'HAVE_SYS_SELECT_H': 1,
 'HAVE_SYS_SENDFILE_H': 1,
 'HAVE_SYS_SOCKET_H': 1,
 'HAVE_SYS_SOUNDCARD_H': 1,
 'HAVE_SYS_STATVFS_H': 1,
 'HAVE_SYS_STAT_H': 1,
 'HAVE_SYS_SYSCALL_H': 1,
 'HAVE_SYS_SYSMACROS_H': 1,
 'HAVE_SYS_SYS_DOMAIN_H': 0,
 'HAVE_SYS_TERMIO_H': 0,
 'HAVE_SYS_TIMERFD_H': 1,
 'HAVE_SYS_TIMES_H': 1,
 'HAVE_SYS_TIME_H': 1,
 'HAVE_SYS_TYPES_H': 1,
 'HAVE_SYS_UIO_H': 1,
 'HAVE_SYS_UN_H': 1,
 'HAVE_SYS_UTSNAME_H': 1,
 'HAVE_SYS_WAIT_H': 1,
 'HAVE_SYS_XATTR_H': 1,
 'HAVE_TCGETPGRP': 1,
 'HAVE_TCSETPGRP': 1,
 'HAVE_TEMPNAM': 1,
 'HAVE_TERMIOS_H': 1,
 'HAVE_TERM_H': 1,
 'HAVE_TIMEGM': 1,
 'HAVE_TIMERFD_CREATE': 1,
 'HAVE_TIMES': 1,
 'HAVE_TMPFILE': 1,
 'HAVE_TMPNAM': 1,
 'HAVE_TMPNAM_R': 1,
 'HAVE_TM_ZONE': 1,
 'HAVE_TRUNCATE': 1,
 'HAVE_TTYNAME_R': 1,
 'HAVE_TZNAME': 0,
 'HAVE_UMASK': 1,
 'HAVE_UNAME': 1,
 'HAVE_UNISTD_H': 1,
 'HAVE_UNLINKAT': 1,
 'HAVE_UNLOCKPT': 1,
 'HAVE_UNSHARE': 1,
 'HAVE_USABLE_WCHAR_T': 0,
 'HAVE_UTIL_H': 0,
 'HAVE_UTIMENSAT': 1,
 'HAVE_UTIMES': 1,
 'HAVE_UTIME_H': 1,
 'HAVE_UTMP_H': 1,
 'HAVE_UT_NAMESIZE': 1,
 'HAVE_UUID_CREATE': 0,
 'HAVE_UUID_ENC_BE': 0,
 'HAVE_UUID_GENERATE_TIME_SAFE': 1,
 'HAVE_UUID_GENERATE_TIME_SAFE_STABLE_MAC': 0,
 'HAVE_UUID_H': 0,
 'HAVE_UUID_UUID_H': 1,
 'HAVE_VFORK': 1,
 'HAVE_WAIT': 1,
 'HAVE_WAIT3': 1,
 'HAVE_WAIT4': 1,
 'HAVE_WAITID': 1,
 'HAVE_WAITPID': 1,
 'HAVE_WCHAR_H': 1,
 'HAVE_WCSCOLL': 1,
 'HAVE_WCSFTIME': 1,
 'HAVE_WCSXFRM': 1,
 'HAVE_WMEMCMP': 1,
 'HAVE_WORKING_TZSET': 1,
 'HAVE_WRITEV': 1,
 'HAVE_ZDICT_H': 0,
 'HAVE_ZLIB_COPY': 1,
 'HAVE_ZLIB_H': 0,
 'HAVE_ZSTD_H': 0,
 'HAVE__GETPTY': 0,
 'HAVE___UINT128_T': 1,
 'HOSTRUNNER': '',
 'HOST_GNU_TYPE': 'x86_64-pc-linux-gnu',
 'INCLDIRSTOMAKE': '{BUILDROOT}/include {BUILDROOT}/include '
                   '{BUILDROOT}/include/python3.14 '
                   '{BUILDROOT}/include/python3.14',
 'INCLUDEDIR': '{BUILDROOT}/include',
 'INCLUDEPY': '{BUILDROOT}/include/python3.14',
 'INSTALL': '/usr/bin/install -c',
 'INSTALL_DATA': '/usr/bin/install -c -m 644',
 'INSTALL_MIMALLOC': 'yes',
 'INSTALL_PROGRAM': '/usr/bin/install -c',
 'INSTALL_SCRIPT': '/usr/bin/install -c',
 'INSTALL_SHARED': '/usr/bin/install -c -m 755',
 'INSTSONAME': 'libpython3.14.a',
 'IO_H': 'Modules/_io/_iomodule.h',
 'IO_OBJS': '\\',
 'IPHONEOS_DEPLOYMENT_TARGET': '',
 'JIT_DEPS': '\\',
 'LDCXXSHARED': '{TOOLCHAIN}/bin/x86_64-linux-gnu-g++ -pthread -shared '
                '-Wl,--build-id=sha1 -Wl,--rpath={BUILDROOT}/lib '
                '-L{BUILDROOT}/lib -L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib',
 'LDFLAGS': '-Wl,--build-id=sha1 -Wl,--rpath={BUILDROOT}/lib -L{BUILDROOT}/lib '
            '-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib',
 'LDLIBRARY': 'libpython3.14.a',
 'LDLIBRARYDIR': '',
 'LDSHARED': '{TOOLCHAIN}/bin/x86_64-linux-gnu-gcc -pthread -shared '
             '-Wl,--build-id=sha1 -Wl,--rpath={BUILDROOT}/lib '
             '-L{BUILDROOT}/lib -L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib',
 'LDVERSION': '3.14',
 'LIBC': '',
 'LIBDEST': '{BUILDROOT}/lib/python3.14',
 'LIBDIR': '{BUILDROOT}/lib',
 'LIBEXPAT_A': 'Modules/expat/libexpat.a',
 'LIBEXPAT_CFLAGS': '-I./Modules/expat -fno-strict-overflow -Wsign-compare '
                    '-DNDEBUG -g -O3 -Wall -Wno-coverage-mismatch -g '
                    '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
                    '-I{BUILDROOT}/include/ncursesw '
                    '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                    '-fno-semantic-interposition -std=c11 -Wextra '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Wstrict-prototypes -fvisibility=hidden -fprofile-use '
                    '-fprofile-correction -I./Include/internal '
                    '-I./Include/internal/mimalloc -I. -I./Include '
                    '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
                    '-I{BUILDROOT}/include/ncursesw '
                    '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include -fPIC',
 'LIBEXPAT_HEADERS': '\\',
 'LIBEXPAT_OBJS': '\\',
 'LIBHACL_BLAKE2_HEADERS': '\\',
 'LIBHACL_BLAKE2_LIB_SHARED': '\\',
 'LIBHACL_BLAKE2_LIB_STATIC': 'Modules/_hacl/libHacl_Hash_BLAKE2.a',
 'LIBHACL_BLAKE2_OBJS': '\\',
 'LIBHACL_BLAKE2_SIMD128_CFLAGS': '-msse -msse2 -msse3 -msse4.1 -msse4.2 '
                                  '-DHACL_CAN_COMPILE_VEC128',
 'LIBHACL_BLAKE2_SIMD128_OBJS': 'Modules/_hacl/Hacl_Hash_Blake2s_Simd128.o',
 'LIBHACL_BLAKE2_SIMD256_CFLAGS': '-mavx2 -DHACL_CAN_COMPILE_VEC256',
 'LIBHACL_BLAKE2_SIMD256_OBJS': 'Modules/_hacl/Hacl_Hash_Blake2b_Simd256.o',
 'LIBHACL_CFLAGS': '-I./Modules/_hacl -I./Modules/_hacl/include -D_BSD_SOURCE '
                   '-D_DEFAULT_SOURCE -DLINUX_NO_EXPLICIT_BZERO '
                   '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall '
                   '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
                   '-I{BUILDROOT}/include/readline '
                   '-I{BUILDROOT}/include/ncursesw '
                   '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                   '-fno-semantic-interposition -std=c11 -Wextra '
                   '-Wno-unused-parameter -Wno-missing-field-initializers '
                   '-Wstrict-prototypes -fvisibility=hidden -fprofile-use '
                   '-fprofile-correction -I./Include/internal '
                   '-I./Include/internal/mimalloc -I. -I./Include '
                   '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
                   '-I{BUILDROOT}/include/ncursesw '
                   '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include -fPIC',
 'LIBHACL_HEADERS': '\\',
 'LIBHACL_HMAC_HEADERS': '\\',
 'LIBHACL_HMAC_LIB_SHARED': '\\',
 'LIBHACL_HMAC_LIB_STATIC': 'Modules/_hacl/libHacl_HMAC.a',
 'LIBHACL_HMAC_OBJS': '\\',
 'LIBHACL_LDFLAGS': '',
 'LIBHACL_MD5_HEADERS': '\\',
 'LIBHACL_MD5_LIB_SHARED': '\\',
 'LIBHACL_MD5_LIB_STATIC': 'Modules/_hacl/libHacl_Hash_MD5.a',
 'LIBHACL_MD5_OBJS': '\\',
 'LIBHACL_SHA1_HEADERS': '\\',
 'LIBHACL_SHA1_LIB_SHARED': '\\',
 'LIBHACL_SHA1_LIB_STATIC': 'Modules/_hacl/libHacl_Hash_SHA1.a',
 'LIBHACL_SHA1_OBJS': '\\',
 'LIBHACL_SHA2_HEADERS': '\\',
 'LIBHACL_SHA2_LIB_SHARED': '\\',
 'LIBHACL_SHA2_LIB_STATIC': 'Modules/_hacl/libHacl_Hash_SHA2.a',
 'LIBHACL_SHA2_OBJS': '\\',
 'LIBHACL_SHA3_HEADERS': '\\',
 'LIBHACL_SHA3_LIB_SHARED': '\\',
 'LIBHACL_SHA3_LIB_STATIC': 'Modules/_hacl/libHacl_Hash_SHA3.a',
 'LIBHACL_SHA3_OBJS': '\\',
 'LIBM': '-lm',
 'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
                    '-DHAVE_UINT128_T=1 -fno-strict-overflow -Wsign-compare '
                    '-DNDEBUG -g -O3 -Wall -Wno-coverage-mismatch -g '
                    '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
                    '-I{BUILDROOT}/include/ncursesw '
                    '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                    '-fno-semantic-interposition -std=c11 -Wextra '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Wstrict-prototypes -fvisibility=hidden -fprofile-use '
                    '-fprofile-correction -I./Include/internal '
                    '-I./Include/internal/mimalloc -I. -I./Include '
                    '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
                    '-I{BUILDROOT}/include/ncursesw '
                    '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include -fPIC',
 'LIBMPDEC_HEADERS': '\\',
 'LIBMPDEC_OBJS': '\\',
 'LIBOBJDIR': 'Python/',
 'LIBOBJS': '',
 'LIBPC': '{BUILDROOT}/lib/pkgconfig',
 'LIBPL': '{BUILDROOT}/lib/python3.14/config-3.14-x86_64-linux-gnu',
 'LIBPYTHON': '',
 'LIBRARY': 'libpython3.14.a',
 'LIBRARY_DEPS': 'libpython3.14.a',
 'LIBRARY_OBJS': '\\',
 'LIBRARY_OBJS_OMIT_FROZEN': '\\',
 'LIBS': '-lpthread -ldl  -lutil',
 'LIBSUBDIRS': 'asyncio \\',
 'LINKCC': '{TOOLCHAIN}/bin/x86_64-linux-gnu-gcc -pthread',
 'LINKFORSHARED': '-Xlinker -export-dynamic',
 'LINK_PYTHON_DEPS': 'libpython3.14.a',
 'LINK_PYTHON_OBJS': '\\',
 'LIPO_32BIT_FLAGS': '',
 'LIPO_INTEL64_FLAGS': '',
 'LLVM_PROF_ERR': 'no',
 'LLVM_PROF_FILE': '',
 'LLVM_PROF_MERGER': 'true',
 'LN': 'ln',
 'LOCALMODLIBS': '-lm                      -lreadline -ltinfow',
 'MACHDEP': 'linux',
 'MACHDEP_OBJS': '',
 'MACHDESTLIB': '{BUILDROOT}/lib/python3.14',
 'MACOSX_DEPLOYMENT_TARGET': '',
 'MAJOR_IN_MKDEV': 0,
 'MAJOR_IN_SYSMACROS': 1,
 'MAKESETUP': './Modules/makesetup',
 'MANDIR': '{BUILDROOT}/share/man',
 'MIMALLOC_HEADERS': '\\',
 'MKDIR_P': '/usr/bin/mkdir -p',
 'MODBUILT_NAMES': 'array  _asyncio  _bisect  _csv  _heapq  _json  _lsprof  '
                   '_pickle  _queue  _random  _remote_debugging  _struct  '
                   '_interpreters  _interpchannels  _interpqueues  _zoneinfo  '
                   'math  cmath  _statistics  _decimal  binascii  _bz2  _lzma  '
                   '_zstd  zlib  _gdbm  _md5  _sha1  _sha2  _sha3  _blake2  '
                   '_hmac  pyexpat  _elementtree  _codecs_cn  _codecs_hk  '
                   '_codecs_iso2022  _codecs_jp  _codecs_kr  _codecs_tw  '
                   '_multibytecodec  unicodedata  fcntl  grp  mmap  '
                   '_posixsubprocess  resource  select  _socket  syslog  '
                   'termios  _posixshmem  _multiprocessing  _ctypes  _curses  '
                   '_curses_panel  _sqlite3  _ssl  _hashlib  _uuid  atexit  '
                   'faulthandler  posix  _signal  _tracemalloc  _suggestions  '
                   '_datetime  _codecs  _collections  errno  _io  itertools  '
                   '_sre  _sysconfig  _thread  time  _types  _typing  '
                   '_weakref  _abc  _functools  _locale  _opcode  _operator  '
                   '_stat  _symtable  pwd  readline',
 'MODDISABLED_NAMES': '_tkinter  nsl  nis',
 'MODLIBS': '-lm                      -lreadline -ltinfow',
 'MODOBJS': 'Modules/atexitmodule.o  Modules/faulthandler.o  '
            'Modules/posixmodule.o  Modules/signalmodule.o  '
            'Modules/_tracemalloc.o  Modules/_suggestions.o  '
            'Modules/_datetimemodule.o  Modules/_codecsmodule.o  '
            'Modules/_collectionsmodule.o  Modules/errnomodule.o  '
            'Modules/_io/_iomodule.o Modules/_io/iobase.o Modules/_io/fileio.o '
            'Modules/_io/bytesio.o Modules/_io/bufferedio.o '
            'Modules/_io/textio.o Modules/_io/stringio.o  '
            'Modules/itertoolsmodule.o  Modules/_sre/sre.o  '
            'Modules/_sysconfig.o  Modules/_threadmodule.o  '
            'Modules/timemodule.o  Modules/_typesmodule.o  '
            'Modules/_typingmodule.o  Modules/_weakref.o  Modules/_abc.o  '
            'Modules/_functoolsmodule.o  Modules/_localemodule.o  '
            'Modules/_opcode.o  Modules/_operator.o  Modules/_stat.o  '
            'Modules/symtablemodule.o  Modules/pwdmodule.o  Modules/readline.o',
 'MODSHARED_NAMES': 'array _asyncio _bisect _csv _heapq _json _lsprof _pickle '
                    '_queue _random _remote_debugging _struct _interpreters '
                    '_interpchannels _interpqueues _zoneinfo math cmath '
                    '_statistics _decimal binascii _bz2 _lzma _zstd zlib _gdbm '
                    '_md5 _sha1 _sha2 _sha3 _blake2 _hmac pyexpat _elementtree '
                    '_codecs_cn _codecs_hk _codecs_iso2022 _codecs_jp '
                    '_codecs_kr _codecs_tw _multibytecodec unicodedata fcntl '
                    'grp mmap _posixsubprocess resource select _socket syslog '
                    'termios _posixshmem _multiprocessing _ctypes _curses '
                    '_curses_panel _sqlite3 _ssl _hashlib _uuid',
 'MODULE_ARRAY_STATE': 'yes',
 'MODULE_ATEXIT_LDFLAGS': '',
 'MODULE_BINASCII_CFLAGS': '-DUSE_ZLIB_CRC32 -I{BUILDROOT}/include',
 'MODULE_BINASCII_LDFLAGS': '-L{BUILDROOT}/lib -lz',
 'MODULE_BINASCII_STATE': 'yes',
 'MODULE_CMATH_DEPS': './Modules/_math.h',
 'MODULE_CMATH_LDFLAGS': '-lm',
 'MODULE_CMATH_STATE': 'yes',
 'MODULE_DEPS_SHARED': 'Modules/config.c',
 'MODULE_DEPS_STATIC': 'Modules/config.c',
 'MODULE_ERRNO_LDFLAGS': '',
 'MODULE_FAULTHANDLER_LDFLAGS': '',
 'MODULE_FCNTL_LDFLAGS': '',
 'MODULE_FCNTL_STATE': 'yes',
 'MODULE_GRP_STATE': 'yes',
 'MODULE_ITERTOOLS_LDFLAGS': '',
 'MODULE_MATH_DEPS': './Modules/_math.h',
 'MODULE_MATH_LDFLAGS': '-lm',
 'MODULE_MATH_STATE': 'yes',
 'MODULE_MMAP_STATE': 'yes',
 'MODULE_OBJS': '\\',
 'MODULE_POSIX_LDFLAGS': '',
 'MODULE_PWD_LDFLAGS': '',
 'MODULE_PWD_STATE': 'yes',
 'MODULE_PYEXPAT_CFLAGS': '-I./Modules/expat',
 'MODULE_PYEXPAT_DEPS': '\\ Modules/expat/libexpat.a',
 'MODULE_PYEXPAT_LDFLAGS': '-lm Modules/expat/libexpat.a',
 'MODULE_PYEXPAT_STATE': 'yes',
 'MODULE_READLINE_STATE': 'missing',
 'MODULE_RESOURCE_STATE': 'yes',
 'MODULE_SELECT_STATE': 'yes',
 'MODULE_SYSLOG_STATE': 'yes',
 'MODULE_TERMIOS_STATE': 'yes',
 'MODULE_TIME_LDFLAGS': '',
 'MODULE_TIME_STATE': 'yes',
 'MODULE_UNICODEDATA_DEPS': './Modules/unicodedata_db.h '
                            './Modules/unicodename_db.h',
 'MODULE_UNICODEDATA_STATE': 'yes',
 'MODULE_XXLIMITED_35_STATE': 'disabled',
 'MODULE_XXLIMITED_STATE': 'disabled',
 'MODULE_XXSUBTYPE_STATE': 'disabled',
 'MODULE_ZLIB_CFLAGS': '-I{BUILDROOT}/include',
 'MODULE_ZLIB_LDFLAGS': '-L{BUILDROOT}/lib -lz',
 'MODULE_ZLIB_STATE': 'yes',
 'MODULE__ABC_LDFLAGS': '',
 'MODULE__ASYNCIO_STATE': 'yes',
 'MODULE__BISECT_STATE': 'yes',
 'MODULE__BLAKE2_CFLAGS': '-I./Modules/_hacl -I./Modules/_hacl/include '
                          '-D_BSD_SOURCE -D_DEFAULT_SOURCE '
                          '-DLINUX_NO_EXPLICIT_BZERO -fno-strict-overflow '
                          '-Wsign-compare -DNDEBUG -g -O3 -Wall '
                          '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
                          '-I{BUILDROOT}/include/readline '
                          '-I{BUILDROOT}/include/ncursesw '
                          '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                          '-fno-semantic-interposition -std=c11 -Wextra '
                          '-Wno-unused-parameter '
                          '-Wno-missing-field-initializers -Wstrict-prototypes '
                          '-fvisibility=hidden -fprofile-use '
                          '-fprofile-correction -I./Include/internal '
                          '-I./Include/internal/mimalloc -I. -I./Include '
                          '-I{BUILDROOT}/include '
                          '-I{BUILDROOT}/include/readline '
                          '-I{BUILDROOT}/include/ncursesw '
                          '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                          '-fPIC',
 'MODULE__BLAKE2_DEPS': './Modules/hashlib.h \\ \\',
 'MODULE__BLAKE2_LDEPS': '\\',
 'MODULE__BLAKE2_LDFLAGS': '\\',
 'MODULE__BLAKE2_STATE': 'yes',
 'MODULE__BZ2_CFLAGS': '',
 'MODULE__BZ2_LDFLAGS': '-lbz2',
 'MODULE__BZ2_STATE': 'yes',
 'MODULE__CODECS_CN_DEPS': './Modules/cjkcodecs/mappings_cn.h '
                           './Modules/cjkcodecs/multibytecodec.h '
                           './Modules/cjkcodecs/cjkcodecs.h',
 'MODULE__CODECS_CN_STATE': 'yes',
 'MODULE__CODECS_HK_DEPS': './Modules/cjkcodecs/mappings_hk.h  '
                           './Modules/cjkcodecs/multibytecodec.h '
                           './Modules/cjkcodecs/cjkcodecs.h',
 'MODULE__CODECS_HK_STATE': 'yes',
 'MODULE__CODECS_ISO2022_DEPS': './Modules/cjkcodecs/mappings_jisx0213_pair.h '
                                './Modules/cjkcodecs/alg_jisx0201.h '
                                './Modules/cjkcodecs/emu_jisx0213_2000.h '
                                './Modules/cjkcodecs/multibytecodec.h '
                                './Modules/cjkcodecs/cjkcodecs.h',
 'MODULE__CODECS_ISO2022_STATE': 'yes',
 'MODULE__CODECS_JP_DEPS': './Modules/cjkcodecs/mappings_jisx0213_pair.h '
                           './Modules/cjkcodecs/alg_jisx0201.h '
                           './Modules/cjkcodecs/emu_jisx0213_2000.h '
                           './Modules/cjkcodecs/mappings_jp.h '
                           './Modules/cjkcodecs/multibytecodec.h '
                           './Modules/cjkcodecs/cjkcodecs.h',
 'MODULE__CODECS_JP_STATE': 'yes',
 'MODULE__CODECS_KR_DEPS': './Modules/cjkcodecs/mappings_kr.h '
                           './Modules/cjkcodecs/multibytecodec.h '
                           './Modules/cjkcodecs/cjkcodecs.h',
 'MODULE__CODECS_KR_STATE': 'yes',
 'MODULE__CODECS_LDFLAGS': '',
 'MODULE__CODECS_TW_DEPS': './Modules/cjkcodecs/mappings_tw.h '
                           './Modules/cjkcodecs/multibytecodec.h '
                           './Modules/cjkcodecs/cjkcodecs.h',
 'MODULE__CODECS_TW_STATE': 'yes',
 'MODULE__COLLECTIONS_LDFLAGS': '',
 'MODULE__CSV_STATE': 'yes',
 'MODULE__CTYPES_CFLAGS': '-fno-strict-overflow -I{BUILDROOT}/include',
 'MODULE__CTYPES_DEPS': './Modules/_ctypes/ctypes.h',
 'MODULE__CTYPES_LDFLAGS': '-L{BUILDROOT}/lib -lffi  -ldl',
 'MODULE__CTYPES_MALLOC_CLOSURE': '',
 'MODULE__CTYPES_STATE': 'yes',
 'MODULE__CTYPES_TEST_DEPS': './Modules/_ctypes/_ctypes_test_generated.c.h',
 'MODULE__CTYPES_TEST_STATE': 'disabled',
 'MODULE__CURSES_CFLAGS': '-D_DEFAULT_SOURCE',
 'MODULE__CURSES_DEPS': './Include/py_curses.h',
 'MODULE__CURSES_LDFLAGS': '-lncursesw -ltinfow',
 'MODULE__CURSES_PANEL_CFLAGS': '-D_DEFAULT_SOURCE  -D_DEFAULT_SOURCE',
 'MODULE__CURSES_PANEL_DEPS': './Include/py_curses.h',
 'MODULE__CURSES_PANEL_LDFLAGS': '-lpanelw -lncursesw -ltinfow',
 'MODULE__CURSES_PANEL_STATE': 'yes',
 'MODULE__CURSES_STATE': 'yes',
 'MODULE__DATETIME_DEPS': './Include/datetime.h',
 'MODULE__DATETIME_LDFLAGS': '-lm',
 'MODULE__DATETIME_STATE': 'yes',
 'MODULE__DBM_STATE': 'missing',
 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 '
                           '-DANSI=1 -DHAVE_UINT128_T=1',
 'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h \\ '
                         'Modules/_decimal/libmpdec/libmpdec.a',
 'MODULE__DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
 'MODULE__DECIMAL_STATE': 'yes',
 'MODULE__ELEMENTTREE_CFLAGS': '-I./Modules/expat',
 'MODULE__ELEMENTTREE_DEPS': './Modules/pyexpat.c \\ Modules/expat/libexpat.a',
 'MODULE__ELEMENTTREE_STATE': 'yes',
 'MODULE__FUNCTOOLS_LDFLAGS': '',
 'MODULE__GDBM_CFLAGS': '',
 'MODULE__GDBM_LDFLAGS': '-lgdbm',
 'MODULE__GDBM_STATE': 'yes',
 'MODULE__HASHLIB_CFLAGS': '-I{BUILDROOT}/include',
 'MODULE__HASHLIB_DEPS': './Modules/hashlib.h',
 'MODULE__HASHLIB_LDFLAGS': '-L{BUILDROOT}/lib   -lcrypto',
 'MODULE__HASHLIB_STATE': 'yes',
 'MODULE__HEAPQ_STATE': 'yes',
 'MODULE__HMAC_CFLAGS': '-I./Modules/_hacl -I./Modules/_hacl/include '
                        '-D_BSD_SOURCE -D_DEFAULT_SOURCE '
                        '-DLINUX_NO_EXPLICIT_BZERO -fno-strict-overflow '
                        '-Wsign-compare -DNDEBUG -g -O3 -Wall '
                        '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
                        '-I{BUILDROOT}/include/readline '
                        '-I{BUILDROOT}/include/ncursesw '
                        '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                        '-fno-semantic-interposition -std=c11 -Wextra '
                        '-Wno-unused-parameter -Wno-missing-field-initializers '
                        '-Wstrict-prototypes -fvisibility=hidden -fprofile-use '
                        '-fprofile-correction -I./Include/internal '
                        '-I./Include/internal/mimalloc -I. -I./Include '
                        '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
                        '-I{BUILDROOT}/include/ncursesw '
                        '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                        '-fPIC',
 'MODULE__HMAC_DEPS': './Modules/hashlib.h \\ \\',
 'MODULE__HMAC_LDEPS': '\\',
 'MODULE__HMAC_LDFLAGS': '\\',
 'MODULE__HMAC_STATE': 'yes',
 'MODULE__INTERPCHANNELS_STATE': 'yes',
 'MODULE__INTERPQUEUES_STATE': 'yes',
 'MODULE__INTERPRETERS_STATE': 'yes',
 'MODULE__IO_CFLAGS': '-I./Modules/_io',
 'MODULE__IO_DEPS': './Modules/_io/_iomodule.h',
 'MODULE__IO_LDFLAGS': '',
 'MODULE__IO_STATE': 'yes',
 'MODULE__JSON_STATE': 'yes',
 'MODULE__LOCALE_LDFLAGS': '',
 'MODULE__LSPROF_STATE': 'yes',
 'MODULE__LZMA_CFLAGS': '-I{BUILDROOT}/include',
 'MODULE__LZMA_LDFLAGS': '-L{BUILDROOT}/lib -llzma',
 'MODULE__LZMA_STATE': 'yes',
 'MODULE__MD5_CFLAGS': '-I./Modules/_hacl -I./Modules/_hacl/include '
                       '-D_BSD_SOURCE -D_DEFAULT_SOURCE '
                       '-DLINUX_NO_EXPLICIT_BZERO -fno-strict-overflow '
                       '-Wsign-compare -DNDEBUG -g -O3 -Wall '
                       '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
                       '-I{BUILDROOT}/include/readline '
                       '-I{BUILDROOT}/include/ncursesw '
                       '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                       '-fno-semantic-interposition -std=c11 -Wextra '
                       '-Wno-unused-parameter -Wno-missing-field-initializers '
                       '-Wstrict-prototypes -fvisibility=hidden -fprofile-use '
                       '-fprofile-correction -I./Include/internal '
                       '-I./Include/internal/mimalloc -I. -I./Include '
                       '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
                       '-I{BUILDROOT}/include/ncursesw '
                       '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                       '-fPIC',
 'MODULE__MD5_DEPS': './Modules/hashlib.h \\ \\',
 'MODULE__MD5_LDEPS': '\\',
 'MODULE__MD5_LDFLAGS': '\\',
 'MODULE__MD5_STATE': 'yes',
 'MODULE__MULTIBYTECODEC_DEPS': './Modules/cjkcodecs/multibytecodec.h',
 'MODULE__MULTIBYTECODEC_STATE': 'yes',
 'MODULE__MULTIPROCESSING_CFLAGS': '-I./Modules/_multiprocessing',
 'MODULE__MULTIPROCESSING_STATE': 'yes',
 'MODULE__OPCODE_LDFLAGS': '',
 'MODULE__OPERATOR_LDFLAGS': '',
 'MODULE__PICKLE_STATE': 'yes',
 'MODULE__POSIXSHMEM_CFLAGS': '-I./Modules/_multiprocessing',
 'MODULE__POSIXSHMEM_LDFLAGS': '-lrt',
 'MODULE__POSIXSHMEM_STATE': 'yes',
 'MODULE__POSIXSUBPROCESS_STATE': 'yes',
 'MODULE__QUEUE_STATE': 'yes',
 'MODULE__RANDOM_STATE': 'yes',
 'MODULE__REMOTE_DEBUGGING_STATE': 'yes',
 'MODULE__SCPROXY_STATE': 'n/a',
 'MODULE__SHA1_CFLAGS': '-I./Modules/_hacl -I./Modules/_hacl/include '
                        '-D_BSD_SOURCE -D_DEFAULT_SOURCE '
                        '-DLINUX_NO_EXPLICIT_BZERO -fno-strict-overflow '
                        '-Wsign-compare -DNDEBUG -g -O3 -Wall '
                        '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
                        '-I{BUILDROOT}/include/readline '
                        '-I{BUILDROOT}/include/ncursesw '
                        '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                        '-fno-semantic-interposition -std=c11 -Wextra '
                        '-Wno-unused-parameter -Wno-missing-field-initializers '
                        '-Wstrict-prototypes -fvisibility=hidden -fprofile-use '
                        '-fprofile-correction -I./Include/internal '
                        '-I./Include/internal/mimalloc -I. -I./Include '
                        '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
                        '-I{BUILDROOT}/include/ncursesw '
                        '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                        '-fPIC',
 'MODULE__SHA1_DEPS': './Modules/hashlib.h \\ \\',
 'MODULE__SHA1_LDEPS': '\\',
 'MODULE__SHA1_LDFLAGS': '\\',
 'MODULE__SHA1_STATE': 'yes',
 'MODULE__SHA2_CFLAGS': '-I./Modules/_hacl -I./Modules/_hacl/include '
                        '-D_BSD_SOURCE -D_DEFAULT_SOURCE '
                        '-DLINUX_NO_EXPLICIT_BZERO -fno-strict-overflow '
                        '-Wsign-compare -DNDEBUG -g -O3 -Wall '
                        '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
                        '-I{BUILDROOT}/include/readline '
                        '-I{BUILDROOT}/include/ncursesw '
                        '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                        '-fno-semantic-interposition -std=c11 -Wextra '
                        '-Wno-unused-parameter -Wno-missing-field-initializers '
                        '-Wstrict-prototypes -fvisibility=hidden -fprofile-use '
                        '-fprofile-correction -I./Include/internal '
                        '-I./Include/internal/mimalloc -I. -I./Include '
                        '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
                        '-I{BUILDROOT}/include/ncursesw '
                        '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                        '-fPIC',
 'MODULE__SHA2_DEPS': './Modules/hashlib.h \\ \\',
 'MODULE__SHA2_LDEPS': '\\',
 'MODULE__SHA2_LDFLAGS': '\\',
 'MODULE__SHA2_STATE': 'yes',
 'MODULE__SHA3_CFLAGS': '-I./Modules/_hacl -I./Modules/_hacl/include '
                        '-D_BSD_SOURCE -D_DEFAULT_SOURCE '
                        '-DLINUX_NO_EXPLICIT_BZERO -fno-strict-overflow '
                        '-Wsign-compare -DNDEBUG -g -O3 -Wall '
                        '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
                        '-I{BUILDROOT}/include/readline '
                        '-I{BUILDROOT}/include/ncursesw '
                        '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                        '-fno-semantic-interposition -std=c11 -Wextra '
                        '-Wno-unused-parameter -Wno-missing-field-initializers '
                        '-Wstrict-prototypes -fvisibility=hidden -fprofile-use '
                        '-fprofile-correction -I./Include/internal '
                        '-I./Include/internal/mimalloc -I. -I./Include '
                        '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
                        '-I{BUILDROOT}/include/ncursesw '
                        '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                        '-fPIC',
 'MODULE__SHA3_DEPS': './Modules/hashlib.h \\ \\',
 'MODULE__SHA3_LDEPS': '\\',
 'MODULE__SHA3_LDFLAGS': '\\',
 'MODULE__SHA3_STATE': 'yes',
 'MODULE__SIGNAL_LDFLAGS': '',
 'MODULE__SOCKET_DEPS': './Modules/socketmodule.h ./Modules/addrinfo.h '
                        './Modules/getaddrinfo.c ./Modules/getnameinfo.c',
 'MODULE__SOCKET_LDFLAGS': '',
 'MODULE__SOCKET_STATE': 'yes',
 'MODULE__SQLITE3_CFLAGS': '-I{BUILDROOT}/include  -I./Modules/_sqlite',
 'MODULE__SQLITE3_DEPS': './Modules/_sqlite/connection.h '
                         './Modules/_sqlite/cursor.h '
                         './Modules/_sqlite/microprotocols.h '
                         './Modules/_sqlite/module.h '
                         './Modules/_sqlite/prepare_protocol.h '
                         './Modules/_sqlite/row.h ./Modules/_sqlite/util.h',
 'MODULE__SQLITE3_LDFLAGS': '-L{BUILDROOT}/lib -lsqlite3',
 'MODULE__SQLITE3_STATE': 'yes',
 'MODULE__SRE_LDFLAGS': '',
 'MODULE__SSL_CFLAGS': '-I{BUILDROOT}/include',
 'MODULE__SSL_DEPS': './Modules/_ssl.h ./Modules/_ssl/cert.c '
                     './Modules/_ssl/debughelpers.c ./Modules/_ssl/misc.c '
                     './Modules/_ssl_data_111.h ./Modules/_ssl_data_300.h '
                     './Modules/socketmodule.h',
 'MODULE__SSL_LDFLAGS': '-L{BUILDROOT}/lib  -lssl -lcrypto',
 'MODULE__SSL_STATE': 'yes',
 'MODULE__STATISTICS_LDFLAGS': '-lm',
 'MODULE__STATISTICS_STATE': 'yes',
 'MODULE__STAT_LDFLAGS': '',
 'MODULE__STRUCT_STATE': 'yes',
 'MODULE__SUGGESTIONS_LDFLAGS': '',
 'MODULE__SYMTABLE_LDFLAGS': '',
 'MODULE__SYSCONFIG_LDFLAGS': '',
 'MODULE__TESTBUFFER_STATE': 'disabled',
 'MODULE__TESTCAPI_DEPS': './Modules/_testcapi/parts.h '
                          './Modules/_testcapi/util.h',
 'MODULE__TESTCAPI_STATE': 'disabled',
 'MODULE__TESTCLINIC_LIMITED_STATE': 'disabled',
 'MODULE__TESTCLINIC_STATE': 'disabled',
 'MODULE__TESTIMPORTMULTIPLE_STATE': 'disabled',
 'MODULE__TESTINTERNALCAPI_DEPS': './Modules/_testinternalcapi/parts.h',
 'MODULE__TESTINTERNALCAPI_STATE': 'disabled',
 'MODULE__TESTLIMITEDCAPI_DEPS': './Modules/_testlimitedcapi/testcapi_long.h '
                                 './Modules/_testlimitedcapi/parts.h '
                                 './Modules/_testlimitedcapi/util.h',
 'MODULE__TESTLIMITEDCAPI_STATE': 'disabled',
 'MODULE__TESTMULTIPHASE_STATE': 'disabled',
 'MODULE__TESTSINGLEPHASE_STATE': 'disabled',
 'MODULE__THREAD_LDFLAGS': '',
 'MODULE__TKINTER_STATE': 'missing',
 'MODULE__TRACEMALLOC_LDFLAGS': '',
 'MODULE__TYPES_LDFLAGS': '',
 'MODULE__TYPES_STATE': 'yes',
 'MODULE__TYPING_LDFLAGS': '',
 'MODULE__TYPING_STATE': 'yes',
 'MODULE__UUID_CFLAGS': '',
 'MODULE__UUID_LDFLAGS': '-luuid',
 'MODULE__UUID_STATE': 'yes',
 'MODULE__WEAKREF_LDFLAGS': '',
 'MODULE__XXTESTFUZZ_STATE': 'disabled',
 'MODULE__ZONEINFO_STATE': 'yes',
 'MODULE__ZSTD_CFLAGS': '-I{BUILDROOT}/include',
 'MODULE__ZSTD_DEPS': './Modules/_zstd/_zstdmodule.h ./Modules/_zstd/buffer.h '
                      './Modules/_zstd/zstddict.h',
 'MODULE__ZSTD_LDFLAGS': '-L{BUILDROOT}/lib -lzstd',
 'MODULE__ZSTD_STATE': 'yes',
 'MULTIARCH': 'x86_64-linux-gnu',
 'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"x86_64-linux-gnu\\"',
 'MVWDELCH_IS_EXPRESSION': 1,
 'NO_AS_NEEDED': '-Wl,--no-as-needed',
 'OBJECT_OBJS': '\\',
 'OPT': '-DNDEBUG -g -O3 -Wall',
 'PACKAGE_BUGREPORT': 0,
 'PACKAGE_NAME': 0,
 'PACKAGE_STRING': 0,
 'PACKAGE_TARNAME': 0,
 'PACKAGE_URL': 0,
 'PACKAGE_VERSION': 0,
 'PARSER_HEADERS': '\\',
 'PARSER_OBJS': '\\ \\ \\ Parser/myreadline.o',
 'PEGEN_HEADERS': '\\',
 'PEGEN_OBJS': '\\',
 'PGO_PROF_GEN_FLAG': '-fprofile-generate -fprofile-update=atomic',
 'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
 'PLATLIBDIR': 'lib',
 'POBJS': '\\',
 'POSIX_SEMAPHORES_NOT_ENABLED': 0,
 'PROFILE_TASK': '-m test --pgo --timeout=',
 'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
 'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
 'PURIFY': '',
 'PY3LIBRARY': '',
 'PYLONG_BITS_IN_DIGIT': 0,
 'PYTHON': 'python',
 'PYTHONFRAMEWORK': '',
 'PYTHONFRAMEWORKDIR': 'no-framework',
 'PYTHONFRAMEWORKINSTALLDIR': '',
 'PYTHONFRAMEWORKINSTALLNAMEPREFIX': '',
 'PYTHONFRAMEWORKPREFIX': '',
 'PYTHONPATH': '',
 'PYTHON_FOR_BUILD': './python -E',
 'PYTHON_FOR_BUILD_DEPS': 'python',
 'PYTHON_FOR_FREEZE': './_bootstrap_python',
 'PYTHON_FOR_REGEN': '',
 'PYTHON_HEADERS': '\\',
 'PYTHON_OBJS': '\\',
 'PY_BUILTIN_HASHLIB_HASHES': '"blake2,md5,sha1,sha2,sha3"',
 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g '
                             '-O3 -Wall -Wno-coverage-mismatch -g '
                             '-I{BUILDROOT}/include '
                             '-I{BUILDROOT}/include/readline '
                             '-I{BUILDROOT}/include/ncursesw '
                             '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                             '-fno-semantic-interposition -std=c11 -Wextra '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes -fvisibility=hidden '
                             '-fprofile-use -fprofile-correction '
                             '-I./Include/internal '
                             '-I./Include/internal/mimalloc -I. -I./Include '
                             '-I{BUILDROOT}/include '
                             '-I{BUILDROOT}/include/readline '
                             '-I{BUILDROOT}/include/ncursesw '
                             '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                             '-DPy_BUILD_CORE_BUILTIN',
 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall '
              '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
              '-I{BUILDROOT}/include/readline -I{BUILDROOT}/include/ncursesw '
              '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include',
 'PY_CFLAGS_NODIST': '-fno-semantic-interposition -std=c11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -fvisibility=hidden -fprofile-use '
                     '-fprofile-correction -I./Include/internal '
                     '-I./Include/internal/mimalloc',
 'PY_COERCE_C_LOCALE': 1,
 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall '
                   '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
                   '-I{BUILDROOT}/include/readline '
                   '-I{BUILDROOT}/include/ncursesw '
                   '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                   '-fno-semantic-interposition -std=c11 -Wextra '
                   '-Wno-unused-parameter -Wno-missing-field-initializers '
                   '-Wstrict-prototypes -fvisibility=hidden -fprofile-use '
                   '-fprofile-correction -I./Include/internal '
                   '-I./Include/internal/mimalloc -I. -I./Include '
                   '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
                   '-I{BUILDROOT}/include/ncursesw '
                   '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                   '-DPy_BUILD_CORE',
 'PY_CORE_LDFLAGS': '-Wl,--build-id=sha1 -Wl,--rpath={BUILDROOT}/lib '
                    '-L{BUILDROOT}/lib '
                    '-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib '
                    '-fno-semantic-interposition',
 'PY_CPPFLAGS': '-I. -I./Include -I{BUILDROOT}/include '
                '-I{BUILDROOT}/include/readline -I{BUILDROOT}/include/ncursesw '
                '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include',
 'PY_ENABLE_SHARED': 0,
 'PY_HAVE_PERF_TRAMPOLINE': 1,
 'PY_LDFLAGS': '-Wl,--build-id=sha1 -Wl,--rpath={BUILDROOT}/lib '
               '-L{BUILDROOT}/lib -L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib',
 'PY_LDFLAGS_NODIST': '-fno-semantic-interposition',
 'PY_LDFLAGS_NOLTO': '-Wl,--build-id=sha1 -Wl,--rpath={BUILDROOT}/lib '
                     '-L{BUILDROOT}/lib '
                     '-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib',
 'PY_SQLITE_ENABLE_LOAD_EXTENSION': 0,
 'PY_SQLITE_HAVE_SERIALIZE': 1,
 'PY_SSL_DEFAULT_CIPHERS': 2,
 'PY_SSL_DEFAULT_CIPHER_STRING': 0,
 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 '
                        '-Wall -Wno-coverage-mismatch -g -I{BUILDROOT}/include '
                        '-I{BUILDROOT}/include/readline '
                        '-I{BUILDROOT}/include/ncursesw '
                        '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                        '-fno-semantic-interposition -std=c11 -Wextra '
                        '-Wno-unused-parameter -Wno-missing-field-initializers '
                        '-Wstrict-prototypes -fvisibility=hidden -fprofile-use '
                        '-fprofile-correction -I./Include/internal '
                        '-I./Include/internal/mimalloc -I. -I./Include '
                        '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
                        '-I{BUILDROOT}/include/ncursesw '
                        '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include',
 'PY_SUPPORT_TIER': 1,
 'Py_DEBUG': 0,
 'Py_ENABLE_SHARED': 0,
 'Py_GIL_DISABLED': 0,
 'Py_HASH_ALGORITHM': 0,
 'Py_REMOTE_DEBUG': 1,
 'Py_RL_STARTUP_HOOK_TAKES_ARGS': 0,
 'Py_STATS': 0,
 'Py_SUNOS_VERSION': 0,
 'Py_TAIL_CALL_INTERP': 0,
 'Py_TRACE_REFS': 0,
 'QUICKTESTOPTS': '-x test_subprocess test_io \\',
 'READELF': '@READELF@',
 'RESSRCDIR': '',
 'RETSIGTYPE': 'void',
 'RUNSHARED': '',
 'SCRIPTDIR': '{BUILDROOT}/lib',
 'SCRIPT_IDLE': 'build/scripts-3.14/idle3.14',
 'SCRIPT_PYDOC': 'build/scripts-3.14/pydoc3.14',
 'SETPGRP_HAVE_ARG': 0,
 'SHAREDMODS': 'Modules/array.cpython-314-x86_64-linux-gnu.so '
               'Modules/_asyncio.cpython-314-x86_64-linux-gnu.so '
               'Modules/_bisect.cpython-314-x86_64-linux-gnu.so '
               'Modules/_csv.cpython-314-x86_64-linux-gnu.so '
               'Modules/_heapq.cpython-314-x86_64-linux-gnu.so '
               'Modules/_json.cpython-314-x86_64-linux-gnu.so '
               'Modules/_lsprof.cpython-314-x86_64-linux-gnu.so '
               'Modules/_pickle.cpython-314-x86_64-linux-gnu.so '
               'Modules/_queue.cpython-314-x86_64-linux-gnu.so '
               'Modules/_random.cpython-314-x86_64-linux-gnu.so '
               'Modules/_remote_debugging.cpython-314-x86_64-linux-gnu.so '
               'Modules/_struct.cpython-314-x86_64-linux-gnu.so '
               'Modules/_interpreters.cpython-314-x86_64-linux-gnu.so '
               'Modules/_interpchannels.cpython-314-x86_64-linux-gnu.so '
               'Modules/_interpqueues.cpython-314-x86_64-linux-gnu.so '
               'Modules/_zoneinfo.cpython-314-x86_64-linux-gnu.so '
               'Modules/math.cpython-314-x86_64-linux-gnu.so '
               'Modules/cmath.cpython-314-x86_64-linux-gnu.so '
               'Modules/_statistics.cpython-314-x86_64-linux-gnu.so '
               'Modules/_decimal.cpython-314-x86_64-linux-gnu.so '
               'Modules/binascii.cpython-314-x86_64-linux-gnu.so '
               'Modules/_bz2.cpython-314-x86_64-linux-gnu.so '
               'Modules/_lzma.cpython-314-x86_64-linux-gnu.so '
               'Modules/_zstd.cpython-314-x86_64-linux-gnu.so '
               'Modules/zlib.cpython-314-x86_64-linux-gnu.so '
               'Modules/_gdbm.cpython-314-x86_64-linux-gnu.so '
               'Modules/_md5.cpython-314-x86_64-linux-gnu.so '
               'Modules/_sha1.cpython-314-x86_64-linux-gnu.so '
               'Modules/_sha2.cpython-314-x86_64-linux-gnu.so '
               'Modules/_sha3.cpython-314-x86_64-linux-gnu.so '
               'Modules/_blake2.cpython-314-x86_64-linux-gnu.so '
               'Modules/_hmac.cpython-314-x86_64-linux-gnu.so '
               'Modules/pyexpat.cpython-314-x86_64-linux-gnu.so '
               'Modules/_elementtree.cpython-314-x86_64-linux-gnu.so '
               'Modules/_codecs_cn.cpython-314-x86_64-linux-gnu.so '
               'Modules/_codecs_hk.cpython-314-x86_64-linux-gnu.so '
               'Modules/_codecs_iso2022.cpython-314-x86_64-linux-gnu.so '
               'Modules/_codecs_jp.cpython-314-x86_64-linux-gnu.so '
               'Modules/_codecs_kr.cpython-314-x86_64-linux-gnu.so '
               'Modules/_codecs_tw.cpython-314-x86_64-linux-gnu.so '
               'Modules/_multibytecodec.cpython-314-x86_64-linux-gnu.so '
               'Modules/unicodedata.cpython-314-x86_64-linux-gnu.so '
               'Modules/fcntl.cpython-314-x86_64-linux-gnu.so '
               'Modules/grp.cpython-314-x86_64-linux-gnu.so '
               'Modules/mmap.cpython-314-x86_64-linux-gnu.so '
               'Modules/_posixsubprocess.cpython-314-x86_64-linux-gnu.so '
               'Modules/resource.cpython-314-x86_64-linux-gnu.so '
               'Modules/select.cpython-314-x86_64-linux-gnu.so '
               'Modules/_socket.cpython-314-x86_64-linux-gnu.so '
               'Modules/syslog.cpython-314-x86_64-linux-gnu.so '
               'Modules/termios.cpython-314-x86_64-linux-gnu.so '
               'Modules/_posixshmem.cpython-314-x86_64-linux-gnu.so '
               'Modules/_multiprocessing.cpython-314-x86_64-linux-gnu.so '
               'Modules/_ctypes.cpython-314-x86_64-linux-gnu.so '
               'Modules/_curses.cpython-314-x86_64-linux-gnu.so '
               'Modules/_curses_panel.cpython-314-x86_64-linux-gnu.so '
               'Modules/_sqlite3.cpython-314-x86_64-linux-gnu.so '
               'Modules/_ssl.cpython-314-x86_64-linux-gnu.so '
               'Modules/_hashlib.cpython-314-x86_64-linux-gnu.so '
               'Modules/_uuid.cpython-314-x86_64-linux-gnu.so',
 'SHELL': '/bin/sh -e',
 'SHLIBS': '-lpthread -ldl  -lutil',
 'SHLIB_SUFFIX': '.so',
 'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
 'SITEPATH': '',
 'SIZEOF_DOUBLE': 8,
 'SIZEOF_FLOAT': 4,
 'SIZEOF_FPOS_T': 16,
 'SIZEOF_INT': 4,
 'SIZEOF_LONG': 8,
 'SIZEOF_LONG_DOUBLE': 16,
 'SIZEOF_LONG_LONG': 8,
 'SIZEOF_OFF_T': 8,
 'SIZEOF_PID_T': 4,
 'SIZEOF_PTHREAD_KEY_T': 4,
 'SIZEOF_PTHREAD_T': 8,
 'SIZEOF_SHORT': 2,
 'SIZEOF_SIZE_T': 8,
 'SIZEOF_TIME_T': 8,
 'SIZEOF_UINTPTR_T': 8,
 'SIZEOF_VOID_P': 8,
 'SIZEOF_WCHAR_T': 4,
 'SIZEOF__BOOL': 1,
 'SOABI': 'cpython-314-x86_64-linux-gnu',
 'SRCDIRS': 'Modules   Modules/_ctypes   Modules/_decimal   '
            'Modules/_decimal/libmpdec   Modules/_hacl   Modules/_io   '
            'Modules/_multiprocessing   Modules/_sqlite   Modules/_sre   '
            'Modules/_testcapi   Modules/_testinternalcapi   '
            'Modules/_testlimitedcapi   Modules/_xxtestfuzz   Modules/_zstd   '
            'Modules/cjkcodecs   Modules/expat   Objects   Objects/mimalloc   '
            'Objects/mimalloc/prim   Parser   Parser/tokenizer   '
            'Parser/lexer   Programs   Python   Python/frozen_modules',
 'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
 'STATIC_LIBPYTHON': 1,
 'STDC_HEADERS': 1,
 'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
 'STRIPFLAG': '-s',
 'SUBDIRS': '',
 'SUBDIRSTOO': 'Include Lib Misc',
 'SYSLIBS': '-lm',
 'SYS_SELECT_WITH_SYS_TIME': 1,
 'TESTOPTS': '',
 'TESTPATH': '',
 'TESTPYTHON': './python -E',
 'TESTPYTHONOPTS': '',
 'TESTRUNNER': './python -E -m test',
 'TESTSUBDIRS': 'idlelib/idle_test \\',
 'TESTTIMEOUT': '',
 'TEST_MODULES': 'no',
 'THREAD_STACK_SIZE': 0,
 'TIMEMODULE_LIB': 0,
 'TM_IN_SYS_TIME': 0,
 'TOKENIZER_HEADERS': '\\',
 'TOKENIZER_OBJS': '\\',
 'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
 'UNICODE_DEPS': '\\',
 'UNIVERSALSDK': '',
 'UPDATE_FILE': './Tools/build/update_file.py',
 'USE_COMPUTED_GOTOS': 0,
 'VERSION': '3.14',
 'WEBEX2': 'web_example_pyrepl_jspi',
 'WEBEX2_DIR': './Platforms/emscripten/web_example_pyrepl_jspi/',
 'WEBEX_DIR': './Platforms/emscripten/web_example/',
 'WHEEL_PKG_DIR': '',
 'WINDOW_HAS_FLAGS': 0,
 'WITH_DECIMAL_CONTEXTVAR': 1,
 'WITH_DOC_STRINGS': 1,
 'WITH_DTRACE': 0,
 'WITH_DYLD': 0,
 'WITH_EDITLINE': 0,
 'WITH_LIBINTL': 0,
 'WITH_MIMALLOC': 1,
 'WITH_NEXT_FRAMEWORK': 0,
 'WITH_PYMALLOC': 1,
 'WITH_VALGRIND': 0,
 'X87_DOUBLE_ROUNDING': 0,
 'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
 'ZIP_STDLIB': 'python3.14.zip',
 'abs_builddir': '/home/runner/work/relenv/relenv/src/Python-3.14.5',
 'abs_srcdir': '/home/runner/work/relenv/relenv/src/Python-3.14.5',
 'datarootdir': '{BUILDROOT}/share',
 'exec_prefix': '{BUILDROOT}',
 'host_exec_prefix': '{BUILDROOT}',
 'host_prefix': '{BUILDROOT}',
 'prefix': '{BUILDROOT}',
 'srcdir': '.'}
import pathlib
import sys
import platform
import os
import logging

log = logging.getLogger(__name__)


def build_arch():
    machine = platform.machine()
    return machine.lower()


def get_triplet(machine=None, plat=None):
    if not plat:
        plat = sys.platform
    if not machine:
        machine = build_arch()
    if plat == "darwin":
        return f"{machine}-macos"
    elif plat == "win32":
        return f"{machine}-win"
    elif plat == "linux":
        return f"{machine}-linux-gnu"
    else:
        raise RelenvException("Unknown platform {}".format(platform))


pydir = pathlib.Path(__file__).resolve().parent
if sys.platform == "win32":
    DEFAULT_DATA_DIR = pathlib.Path.home() / "AppData" / "Local" / "relenv"
else:
    DEFAULT_DATA_DIR = pathlib.Path.home() / ".local" / "relenv"

if "RELENV_DATA" in os.environ:
    DATA_DIR = pathlib.Path(os.environ["RELENV_DATA"]).resolve()
else:
    DATA_DIR = DEFAULT_DATA_DIR

buildroot = pydir.parent.parent

toolchain = DATA_DIR / "toolchain" / get_triplet()

build_time_vars = {}
for key in _build_time_vars:
    val = _build_time_vars[key]
    orig = val
    if isinstance(val, str):
        val = val.format(
            BUILDROOT=buildroot,
            TOOLCHAIN=toolchain,
        )
    build_time_vars[key] = val



# This file is dual licensed under the terms of the Apache License, Version
# 2.0, and the BSD License. See the LICENSE file in the root of this repository
# for complete details.

from __future__ import annotations

from cryptography.hazmat.bindings._rust import openssl as rust_openssl
from cryptography.hazmat.primitives.kdf import KeyDerivationFunction

HKDF = rust_openssl.kdf.HKDF
HKDFExpand = rust_openssl.kdf.HKDFExpand

KeyDerivationFunction.register(HKDF)
KeyDerivationFunction.register(HKDFExpand)

__all__ = ["HKDF", "HKDFExpand"]



# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import base64

from libcloud.utils.py3 import b, httplib, urlparse
from libcloud.common.base import JsonResponse, ConnectionUserAndKey
from libcloud.container.base import Container, ContainerImage, ContainerDriver
from libcloud.container.types import ContainerState
from libcloud.container.providers import Provider

try:
    import simplejson as json
except Exception:
    import json


VALID_RESPONSE_CODES = [
    httplib.OK,
    httplib.ACCEPTED,
    httplib.CREATED,
    httplib.NO_CONTENT,
]


class RancherResponse(JsonResponse):
    def parse_error(self):
        parsed = super().parse_error()
        if "fieldName" in parsed:
            return "Field {} is {}: {} - {}".format(
                parsed["fieldName"],
                parsed["code"],
                parsed["message"],
                parsed["detail"],
            )
        else:
            return "{} - {}".format(parsed["message"], parsed["detail"])

    def success(self):
        return self.status in VALID_RESPONSE_CODES


class RancherException(Exception):
    def __init__(self, code, message):
        self.code = code
        self.message = message
        self.args = (code, message)

    def __str__(self):
        return "{} {}".format(self.code, self.message)

    def __repr__(self):
        return "RancherException {} {}".format(self.code, self.message)


class RancherConnection(ConnectionUserAndKey):
    responseCls = RancherResponse
    timeout = 30

    def add_default_headers(self, headers):
        """
        Add parameters that are necessary for every request
        If user and password are specified, include a base http auth
        header
        """
        headers["Content-Type"] = "application/json"
        headers["Accept"] = "application/json"
        if self.key and self.user_id:
            user_b64 = base64.b64encode(b("{}:{}".format(self.user_id, self.key)))
            headers["Authorization"] = "Basic %s" % (user_b64.decode("utf-8"))
        return headers


class RancherContainerDriver(ContainerDriver):
    """
    Driver for Rancher by Rancher Labs.

    This driver is capable of interacting with the Version 1 API of Rancher.
    It currently does NOT support the Version 2 API.

    Example:

        >>> from libcloud.container.providers import get_driver
        >>> from libcloud.container.types import Provider

        >>> driver = get_driver(Provider.RANCHER)
        >>> connection = driver(key="ACCESS_KEY_HERE",
        secret="SECRET_KEY_HERE", host="172.30.0.100", port=8080)

        >>> image = ContainerImage("hastebin", "hastebin", "rlister/hastebin",
        "latest", driver=None)
        >>> newcontainer = connection.deploy_container("myawesomepastebin",
        image, environment={"STORAGE_TYPE": "file"})

    :ivar   baseuri: The URL base path to the API.
    :type   baseuri: ``str``
    """

    type = Provider.RANCHER
    name = "Rancher"
    website = "http://rancher.com"
    connectionCls = RancherConnection
    # Holding off on cluster support for now.
    # Only Environment API interaction enabled.
    supports_clusters = False
    # As in the /v1/
    version = "1"

    def __init__(self, key, secret, secure=True, host="localhost", port=443):
        """
        Creates a new Rancher Container driver.

        :param    key: API key or username to used (required)
        :type     key: ``str``

        :param    secret: Secret password to be used (required)
        :type     secret: ``str``

        :param    secure: Whether to use HTTPS or HTTP.
        :type     secure: ``bool``

        :param    host: Override hostname used for connections. This can also
         be a full URL string, including scheme, port, and base path.
        :type     host: ``str``

        :param    port: Override port used for connections.
        :type     port: ``int``

        :return: A newly initialized driver instance.
        """

        # Parse the Given Host
        if "://" not in host and not host.startswith("//"):
            host = "//" + host
        parsed = urlparse.urlparse(host)

        super().__init__(
            key=key,
            secret=secret,
            secure=False if parsed.scheme == "http" else secure,
            host=parsed.hostname,
            port=parsed.port if parsed.port else port,
        )

        self.baseuri = parsed.path if parsed.path else "/v%s" % self.version

    def ex_list_stacks(self):
        """
        List all Rancher Stacks

        http://docs.rancher.com/rancher/v1.2/en/api/api-resources/environment/

        :rtype: ``list`` of ``dict``
        """

        result = self.connection.request("%s/environments" % self.baseuri).object
        return result["data"]

    def ex_deploy_stack(
        self,
        name,
        description=None,
        docker_compose=None,
        environment=None,
        external_id=None,
        rancher_compose=None,
        start=True,
    ):
        """
        Deploy a new stack.

        http://docs.rancher.com/rancher/v1.2/en/api/api-resources/environment/#create

        :param name: The desired name of the stack. (required)
        :type name: ``str``

        :param description: A desired description for the stack.
        :type description: ``str``

        :param docker_compose: The Docker Compose configuration to use.
        :type docker_compose: ``str``

        :param environment: Environment K/V specific to this stack.
        :type environment: ``dict``

        :param external_id: The externalId of the stack.
        :type external_id: ``str``

        :param rancher_compose: The Rancher Compose configuration for this env.
        :type rancher_compose: ``str``

        :param start: Whether to start this stack on creation.
        :type start: ``bool``

        :return: The newly created stack.
        :rtype: ``dict``
        """

        payload = {
            "description": description,
            "dockerCompose": docker_compose,
            "environment": environment,
            "externalId": external_id,
            "name": name,
            "rancherCompose": rancher_compose,
            "startOnCreate": start,
        }
        data = json.dumps({k: v for (k, v) in payload.items() if v is not None})
        result = self.connection.request(
            "%s/environments" % self.baseuri, data=data, method="POST"
        ).object

        return result

    def ex_get_stack(self, env_id):
        """
        Get a stack by ID

        :param env_id: The stack to be obtained.
        :type env_id: ``str``

        :rtype: ``dict``
        """
        result = self.connection.request("{}/environments/{}".format(self.baseuri, env_id)).object

        return result

    def ex_search_stacks(self, search_params):
        """
        Search for stacks matching certain filters

        i.e. ``{ "name": "awesomestack"}``

        :param search_params: A collection of search parameters to use.
        :type search_params: ``dict``

        :rtype: ``list``
        """
        search_list = []
        for f, v in search_params.items():
            search_list.append(f + "=" + v)
        search_items = "&".join(search_list)
        result = self.connection.request(
            "{}/environments?{}".format(self.baseuri, search_items)
        ).object

        return result["data"]

    def ex_destroy_stack(self, env_id):
        """
        Destroy a stack by ID

        http://docs.rancher.com/rancher/v1.2/en/api/api-resources/environment/#delete

        :param env_id: The stack to be destroyed.
        :type env_id: ``str``

        :return: True if destroy was successful, False otherwise.
        :rtype: ``bool``
        """
        result = self.connection.request(
            "{}/environments/{}".format(self.baseuri, env_id), method="DELETE"
        )
        return result.status in VALID_RESPONSE_CODES

    def ex_activate_stack(self, env_id):
        """
        Activate Services for a stack.

        http://docs.rancher.com/rancher/v1.2/en/api/api-resources/environment/#activateservices

        :param env_id: The stack to activate services for.
        :type env_id: ``str``

        :return: True if activate was successful, False otherwise.
        :rtype: ``bool``
        """
        result = self.connection.request(
            "{}/environments/{}?action=activateservices".format(self.baseuri, env_id),
            method="POST",
        )
        return result.status in VALID_RESPONSE_CODES

    def ex_deactivate_stack(self, env_id):
        """
        Deactivate Services for a stack.

        http://docs.rancher.com/rancher/v1.2/en/api/api-resources/environment/#deactivateservices

        :param env_id: The stack to deactivate services for.
        :type env_id: ``str``

        :return: True if deactivate was successful, False otherwise.
        :rtype: ``bool``
        """

        result = self.connection.request(
            "{}/environments/{}?action=deactivateservices".format(self.baseuri, env_id),
            method="POST",
        )
        return result.status in VALID_RESPONSE_CODES

    def ex_list_services(self):
        """
        List all Rancher Services

        http://docs.rancher.com/rancher/v1.2/en/api/api-resources/service/

        :rtype: ``list`` of ``dict``
        """

        result = self.connection.request("%s/services" % self.baseuri).object
        return result["data"]

    def ex_deploy_service(
        self,
        name,
        image,
        environment_id,
        start=True,
        assign_service_ip_address=None,
        service_description=None,
        external_id=None,
        metadata=None,
        retain_ip=None,
        scale=None,
        scale_policy=None,
        secondary_launch_configs=None,
        selector_container=None,
        selector_link=None,
        vip=None,
        **launch_conf,
    ):
        """
        Deploy a Rancher Service under a stack.

        http://docs.rancher.com/rancher/v1.2/en/api/api-resources/service/#create

        *Any further configuration passed applies to the ``launchConfig``*

        :param name: The desired name of the service. (required)
        :type name: ``str``

        :param image: The Image object to deploy. (required)
        :type image: :class:`libcloud.container.base.ContainerImage`

        :param environment_id: The stack ID this service is tied to. (required)
        :type environment_id: ``str``

        :param start: Whether to start the service on creation.
        :type start: ``bool``

        :param assign_service_ip_address: The IP address to assign the service.
        :type assign_service_ip_address: ``bool``

        :param service_description: The service description.
        :type service_description: ``str``

        :param external_id: The externalId for this service.
        :type external_id: ``str``

        :param metadata: K/V Metadata for this service.
        :type metadata: ``dict``

        :param retain_ip: Whether this service should retain its IP.
        :type retain_ip: ``bool``

        :param scale: The scale of containers in this service.
        :type scale: ``int``

        :param scale_policy: The scaling policy for this service.
        :type scale_policy: ``dict``

        :param secondary_launch_configs: Secondary container launch configs.
        :type secondary_launch_configs: ``list``

        :param selector_container: The selectorContainer for this service.
        :type selector_container: ``str``

        :param selector_link: The selectorLink for this service.
        :type selector_link: ``type``

        :param vip: The VIP to assign to this service.
        :type vip: ``str``

        :return: The newly created service.
        :rtype: ``dict``
        """

        launch_conf["imageUuid"] = (self._degen_image(image),)

        service_payload = {
            "assignServiceIpAddress": assign_service_ip_address,
            "description": service_description,
            "environmentId": environment_id,
            "externalId": external_id,
            "launchConfig": launch_conf,
            "metadata": metadata,
            "name": name,
            "retainIp": retain_ip,
            "scale": scale,
            "scalePolicy": scale_policy,
            "secondary_launch_configs": secondary_launch_configs,
            "selectorContainer": selector_container,
            "selectorLink": selector_link,
            "startOnCreate": start,
            "vip": vip,
        }

        data = json.dumps({k: v for (k, v) in service_payload.items() if v is not None})
        result = self.connection.request(
            "%s/services" % self.baseuri, data=data, method="POST"
        ).object

        return result

    def ex_get_service(self, service_id):
        """
        Get a service by ID

        :param service_id: The service_id to be obtained.
        :type service_id: ``str``

        :rtype: ``dict``
        """
        result = self.connection.request("{}/services/{}".format(self.baseuri, service_id)).object

        return result

    def ex_search_services(self, search_params):
        """
        Search for services matching certain filters

        i.e. ``{ "name": "awesomesause", "environmentId": "1e2"}``

        :param search_params: A collection of search parameters to use.
        :type search_params: ``dict``

        :rtype: ``list``
        """
        search_list = []
        for f, v in search_params.items():
            search_list.append(f + "=" + v)
        search_items = "&".join(search_list)
        result = self.connection.request("{}/services?{}".format(self.baseuri, search_items)).object

        return result["data"]

    def ex_destroy_service(self, service_id):
        """
        Destroy a service by ID

        http://docs.rancher.com/rancher/v1.2/en/api/api-resources/service/#delete

        :param service_id: The service to be destroyed.
        :type service_id: ``str``

        :return: True if destroy was successful, False otherwise.
        :rtype: ``bool``
        """
        result = self.connection.request(
            "{}/services/{}".format(self.baseuri, service_id), method="DELETE"
        )
        return result.status in VALID_RESPONSE_CODES

    def ex_activate_service(self, service_id):
        """
        Activate a service.

        http://docs.rancher.com/rancher/v1.2/en/api/api-resources/service/#activate

        :param service_id: The service to activate services for.
        :type service_id: ``str``

        :return: True if activate was successful, False otherwise.
        :rtype: ``bool``
        """
        result = self.connection.request(
            "{}/services/{}?action=activate".format(self.baseuri, service_id), method="POST"
        )
        return result.status in VALID_RESPONSE_CODES

    def ex_deactivate_service(self, service_id):
        """
        Deactivate a service.

        http://docs.rancher.com/rancher/v1.2/en/api/api-resources/service/#deactivate

        :param service_id: The service to deactivate services for.
        :type service_id: ``str``

        :return: True if deactivate was successful, False otherwise.
        :rtype: ``bool``
        """
        result = self.connection.request(
            "{}/services/{}?action=deactivate".format(self.baseuri, service_id),
            method="POST",
        )
        return result.status in VALID_RESPONSE_CODES

    def list_containers(self):
        """
        List the deployed containers.

        http://docs.rancher.com/rancher/v1.2/en/api/api-resources/container/

        :rtype: ``list`` of :class:`libcloud.container.base.Container`
        """

        result = self.connection.request("%s/containers" % self.baseuri).object
        containers = [self._to_container(value) for value in result["data"]]
        return containers

    def deploy_container(self, name, image, parameters=None, start=True, **config):
        """
        Deploy a new container.

        http://docs.rancher.com/rancher/v1.2/en/api/api-resources/container/#create

        **The following is the Image format used for ``ContainerImage``**

        *For a ``imageuuid``*:

        - ``docker:<hostname>:<port>/<namespace>/<imagename>:<version>``

        *The following applies*:

        - ``id`` = ``<imagename>``
        - ``name`` = ``<imagename>``
        - ``path`` = ``<hostname>:<port>/<namespace>/<imagename>``
        - ``version`` = ``<version>``

        *Any extra configuration can also be passed i.e. "environment"*

        :param name: The desired name of the container. (required)
        :type name: ``str``

        :param image: The Image object to deploy. (required)
        :type image: :class:`libcloud.container.base.ContainerImage`

        :param parameters: Container Image parameters (unused)
        :type  parameters: ``str``

        :param start: Whether to start the container on creation(startOnCreate)
        :type start: ``bool``

        :rtype: :class:`Container`
        """

        payload = {
            "name": name,
            "imageUuid": self._degen_image(image),
            "startOnCreate": start,
        }
        config.update(payload)

        data = json.dumps(config)

        result = self.connection.request(
            "%s/containers" % self.baseuri, data=data, method="POST"
        ).object

        return self._to_container(result)

    def get_container(self, con_id):
        """
        Get a container by ID

        :param con_id: The ID of the container to get
        :type  con_id: ``str``

        :rtype: :class:`libcloud.container.base.Container`
        """
        result = self.connection.request("{}/containers/{}".format(self.baseuri, con_id)).object

        return self._to_container(result)

    def start_container(self, container):
        """
        Start a container

        :param container: The container to be started
        :type  container: :class:`libcloud.container.base.Container`

        :return: The container refreshed with current data
        :rtype: :class:`libcloud.container.base.Container`
        """
        result = self.connection.request(
            "{}/containers/{}?action=start".format(self.baseuri, container.id),
            method="POST",
        ).object

        return self._to_container(result)

    def stop_container(self, container):
        """
        Stop a container

        :param container: The container to be stopped
        :type  container: :class:`libcloud.container.base.Container`

        :return: The container refreshed with current data
        :rtype: :class:`libcloud.container.base.Container`
        """
        result = self.connection.request(
            "{}/containers/{}?action=stop".format(self.baseuri, container.id), method="POST"
        ).object

        return self._to_container(result)

    def ex_search_containers(self, search_params):
        """
        Search for containers matching certain filters

        i.e. ``{ "imageUuid": "docker:mysql", "state": "running"}``

        :param search_params: A collection of search parameters to use.
        :type search_params: ``dict``

        :rtype: ``list``
        """
        search_list = []
        for f, v in search_params.items():
            search_list.append(f + "=" + v)
        search_items = "&".join(search_list)
        result = self.connection.request(
            "{}/containers?{}".format(self.baseuri, search_items)
        ).object

        return result["data"]

    def destroy_container(self, container):
        """
        Remove a container

        :param container: The container to be destroyed
        :type  container: :class:`libcloud.container.base.Container`

        :return: True if the destroy was successful, False otherwise.
        :rtype: ``bool``
        """
        result = self.connection.request(
            "{}/containers/{}".format(self.baseuri, container.id), method="DELETE"
        ).object

        return self._to_container(result)

    def _gen_image(self, imageuuid):
        """
        This function converts a valid Rancher ``imageUuid`` string to a valid
        image object. Only supports docker based images hence `docker:` must
        prefix!!

        Please see the deploy_container() for details on the format.

        :param imageuuid: A valid Rancher image string
            i.e. ``docker:rlister/hastebin:8.0``
        :type imageuuid: ``str``

        :return: Converted ContainerImage object.
        :rtype: :class:`libcloud.container.base.ContainerImage`
        """
        # Obtain just the name(:version) for parsing
        if "/" not in imageuuid:
            # String looks like `docker:mysql:8.0`
            image_name_version = imageuuid.partition(":")[2]
        else:
            # String looks like `docker:oracle/mysql:8.0`
            image_name_version = imageuuid.rpartition("/")[2]
        # Parse based on ':'
        if ":" in image_name_version:
            version = image_name_version.partition(":")[2]
            id = image_name_version.partition(":")[0]
            name = id
        else:
            version = "latest"
            id = image_name_version
            name = id
        # Get our path based on if there was a version
        if version != "latest":
            path = imageuuid.partition(":")[2].rpartition(":")[0]
        else:
            path = imageuuid.partition(":")[2]

        return ContainerImage(
            id=id,
            name=name,
            path=path,
            version=version,
            driver=self.connection.driver,
            extra={"imageUuid": imageuuid},
        )

    def _degen_image(self, image):
        """
        Take in an image object to break down into an ``imageUuid``

        :param image:
        :return:
        """

        # Only supporting docker atm
        image_type = "docker"

        if image.version is not None:
            return image_type + ":" + image.path + ":" + image.version
        else:
            return image_type + ":" + image.path

    def _to_container(self, data):
        """
        Convert container in proper Container instance object
        ** Updating is NOT supported!!

        :param data: API data about container i.e. result.object
        :return: Proper Container object:
         see http://libcloud.readthedocs.io/en/latest/container/api.html

        """
        rancher_state = data["state"]

        # A Removed container is purged after x amt of time.
        # Both of these render the container dead (can't be started later)
        terminate_condition = ["removed", "purged"]

        if "running" in rancher_state:
            state = ContainerState.RUNNING
        elif "stopped" in rancher_state:
            state = ContainerState.STOPPED
        elif "restarting" in rancher_state:
            state = ContainerState.REBOOTING
        elif "error" in rancher_state:
            state = ContainerState.ERROR
        elif any(x in rancher_state for x in terminate_condition):
            state = ContainerState.TERMINATED
        elif data["transitioning"] == "yes":
            # Best we can do for current actions
            state = ContainerState.PENDING
        else:
            state = ContainerState.UNKNOWN

        # Everything contained in the json response is dumped in extra
        extra = data

        return Container(
            id=data["id"],
            name=data["name"],
            image=self._gen_image(data["imageUuid"]),
            ip_addresses=[data["primaryIpAddress"]],
            state=state,
            driver=self.connection.driver,
            extra=extra,
        )



"""
Windows Service module.

.. versionchanged:: 2016.11.0

    Rewritten to use PyWin32
"""

import fnmatch
import logging
import re
import time

import salt.utils.path
import salt.utils.platform
import salt.utils.win_service
from salt.exceptions import CommandExecutionError

try:
    import pywintypes
    import win32service
    import win32serviceutil

    HAS_WIN32_MODS = True
except ImportError:
    HAS_WIN32_MODS = False

log = logging.getLogger(__name__)

# Define the module's virtual name
__virtualname__ = "service"

SERVICE_TYPE = salt.utils.win_service.SERVICE_TYPE
SERVICE_START_TYPE = salt.utils.win_service.SERVICE_START_TYPE
SERVICE_ERROR_CONTROL = salt.utils.win_service.SERVICE_ERROR_CONTROL


def __virtual__():
    """
    Only works on Windows systems with PyWin32 installed
    """
    if not salt.utils.platform.is_windows():
        return False, "Module win_service: module only works on Windows."

    if not HAS_WIN32_MODS:
        return False, "Module win_service: failed to load win32 modules"

    return __virtualname__


def _status_wait(service_name, end_time, service_states):
    """
    Helper function that will wait for the status of the service to match the
    provided status before an end time expires. Used for service stop and start

    .. versionadded:: 2017.7.9,2018.3.4

    Args:

        service_name (str):
            The name of the service

        end_time (float):
            A future time. e.g. time.time() + 10

        service_states (list):
            Services statuses to wait for as returned by info()

    Returns:
        dict: A dictionary containing information about the service.

    :codeauthor: Damon Atkins <https://github.com/damon-atkins>
    """
    info_results = info(service_name)

    while info_results["Status"] in service_states and time.time() < end_time:
        # From Microsoft: Do not wait longer than the wait hint. A good interval
        # is one-tenth of the wait hint but not less than 1 second and not more
        # than 10 seconds.
        # https://docs.microsoft.com/en-us/windows/desktop/services/starting-a-service
        # https://docs.microsoft.com/en-us/windows/desktop/services/stopping-a-service
        # Wait hint is in ms
        wait_time = info_results["Status_WaitHint"]
        # Convert to seconds or 0
        wait_time = wait_time / 1000 if wait_time else 0
        if wait_time < 1:
            wait_time = 1
        elif wait_time > 10:
            wait_time = 10

        time.sleep(wait_time)
        info_results = info(service_name)

    return info_results


def _cmd_quote(cmd):
    r"""
    Helper function to properly format the path to the binary for the service
    Must be wrapped in double quotes to account for paths that have spaces. For
    example:

    ``"C:\Program Files\Path\to\bin.exe"``

    Args:

        cmd (str): Full path to the binary

    Returns:
        str: Properly quoted path to the binary
    """
    # Remove all single and double quotes from the beginning and the end
    pattern = re.compile("^(\\\"|').*|.*(\\\"|')$")
    while pattern.match(cmd) is not None:
        cmd = cmd.strip('"').strip("'")
    # Ensure the path to the binary is wrapped in double quotes to account for
    # spaces in the path
    cmd = f'"{cmd}"'
    return cmd


def get_enabled():
    """
    Return a list of enabled services. Enabled is defined as a service that is
    marked to Auto Start.

    Returns:
        list: A list of enabled services

    CLI Example:

    .. code-block:: bash

        salt '*' service.get_enabled
    """
    raw_services = _get_services()
    services = set()
    for service in raw_services:
        if info(service["ServiceName"])["StartType"] in ["Auto"]:
            services.add(service["ServiceName"])

    return sorted(services)


def get_disabled():
    """
    Return a list of disabled services. Disabled is defined as a service that is
    marked 'Disabled' or 'Manual'.

    Returns:
        list: A list of disabled services.

    CLI Example:

    .. code-block:: bash

        salt '*' service.get_disabled
    """
    raw_services = _get_services()
    services = set()
    for service in raw_services:
        if info(service["ServiceName"])["StartType"] in ["Manual", "Disabled"]:
            services.add(service["ServiceName"])

    return sorted(services)


def available(name):
    """
    Check if a service is available on the system.

    Args:

        name (str): The name of the service to check

    Returns:
        bool: ``True`` if the service is available, ``False`` otherwise

    CLI Example:

    .. code-block:: bash

        salt '*' service.available <service name>
    """
    for service in get_all():
        if name.lower() == service.lower():
            return True

    return False


def missing(name):
    """
    The inverse of service.available.

    Args:

        name (str): The name of the service to check

    Returns:
        bool: ``True`` if the service is missing, ``False`` otherwise

    CLI Example:

    .. code-block:: bash

        salt '*' service.missing <service name>
    """
    return name not in get_all()


def _get_services():
    """
    Returns a list of all services on the system.
    """
    handle_scm = win32service.OpenSCManager(
        None, None, win32service.SC_MANAGER_ENUMERATE_SERVICE
    )

    try:
        services = win32service.EnumServicesStatusEx(handle_scm)
    except AttributeError:
        services = win32service.EnumServicesStatus(handle_scm)
    finally:
        win32service.CloseServiceHandle(handle_scm)

    return services


def get_all():
    """
    Return all installed services

    Returns:
        list: Returns a list of all services on the system.

    CLI Example:

    .. code-block:: bash

        salt '*' service.get_all
    """
    services = _get_services()

    ret = set()
    for service in services:
        ret.add(service["ServiceName"])

    return sorted(ret)


def get_service_name(*args):
    """
    The Display Name is what is displayed in Windows when services.msc is
    executed.  Each Display Name has an associated Service Name which is the
    actual name of the service.  This function allows you to discover the
    Service Name by returning a dictionary of Display Names and Service Names,
    or filter by adding arguments of Display Names.

    If no args are passed, return a dict of all services where the keys are the
    service Display Names and the values are the Service Names.

    If arguments are passed, create a dict of Display Names and Service Names

    Returns:
        dict: A dictionary of display names and service names

    CLI Examples:

    .. code-block:: bash

        salt '*' service.get_service_name
        salt '*' service.get_service_name 'Google Update Service (gupdate)' 'DHCP Client'
    """
    raw_services = _get_services()

    services = dict()
    for raw_service in raw_services:
        if args:
            if (
                raw_service["DisplayName"] in args
                or raw_service["ServiceName"] in args
                or raw_service["ServiceName"].lower() in args
            ):
                services[raw_service["DisplayName"]] = raw_service["ServiceName"]
        else:
            services[raw_service["DisplayName"]] = raw_service["ServiceName"]

    return services


def info(name):
    """
    Get information about a service on the system

    Args:

        name (str):
            The name of the service. This is not the display name. Use
            ``get_service_name`` to find the service name.

    Returns:
        dict: A dictionary containing information about the service.

    CLI Example:

    .. code-block:: bash

        salt '*' service.info spooler
    """
    return salt.utils.win_service.info(name=name)


def start(name, timeout=90):
    """
    Start the specified service.

    .. warning::
        You cannot start a disabled service in Windows. If the service is
        disabled, it will be changed to ``Manual`` start.

    Args:

        name (str): The name of the service to start

        timeout (:obj:`int`, optional):
            The time in seconds to wait for the service to start before
            returning.

            .. versionadded:: 2017.7.9,2018.3.4

            Default is 90 seconds.

    Returns:
        bool: ``True`` if successful, otherwise ``False``. Also returns ``True``
            if the service is already started

    CLI Example:

    .. code-block:: bash

        salt '*' service.start <service name>
    """
    # Set the service to manual if disabled
    if disabled(name):
        modify(name, start_type="Manual")

    try:
        win32serviceutil.StartService(name)
    except pywintypes.error as exc:
        if exc.winerror != 1056:
            raise CommandExecutionError(f"Failed To Start {name}: {exc.strerror}")
        log.debug('Service "%s" is running', name)

    srv_status = _status_wait(
        service_name=name,
        end_time=time.time() + int(timeout),
        service_states=["Start Pending", "Stopped"],
    )

    return srv_status["Status"] == "Running"


def stop(name, timeout=90):
    """
    Stop the specified service

    Args:

        name (str): The name of the service to stop

        timeout (:obj:`int`, optional):
            The time in seconds to wait for the service to stop before
            returning.

            .. versionadded:: 2017.7.9,2018.3.4

            Default is 90 seconds.

    Returns:
        bool: ``True`` if successful, otherwise ``False``. Also returns ``True``
            if the service is already stopped

    CLI Example:

    .. code-block:: bash

        salt '*' service.stop <service name>
    """
    try:
        win32serviceutil.StopService(name)
    except pywintypes.error as exc:
        if exc.winerror != 1062:
            raise CommandExecutionError(f"Failed To Stop {name}: {exc.strerror}")
        log.debug('Service "%s" is not running', name)

    srv_status = _status_wait(
        service_name=name,
        end_time=time.time() + int(timeout),
        service_states=["Running", "Stop Pending"],
    )

    return srv_status["Status"] == "Stopped"


def restart(name, timeout=90):
    """
    Restart the named service. This issues a stop command followed by a start.

    Args:

        name: The name of the service to restart.

            .. note::
                If the name passed is ``salt-minion`` a scheduled task is
                created and executed to restart the salt-minion service.

        timeout (:obj:`int`, optional):
            The time in seconds to wait for the service to stop and start before
            returning.

            .. note::
                The timeout is cumulative meaning it is applied to the stop and
                then to the start command. A timeout of 90 could take up to 180
                seconds if the service is long in stopping and starting

            .. versionadded:: 2017.7.9,2018.3.4

            Default is 90 seconds.

    Returns:
        bool: ``True`` if successful, otherwise ``False``

    CLI Example:

    .. code-block:: bash

        salt '*' service.restart <service name>
    """
    if "salt-minion" in name:
        create_win_salt_restart_task()
        return execute_salt_restart_task()

    return stop(name=name, timeout=timeout) and start(name=name, timeout=timeout)


def create_win_salt_restart_task():
    """
    Create a task in Windows task scheduler to enable restarting the salt-minion

    Returns:
        bool: ``True`` if successful, otherwise ``False``

    CLI Example:

    .. code-block:: bash

        salt '*' service.create_win_salt_restart_task()
    """
    # Updated to use full name for Nessus agent
    cmd = salt.utils.path.which("cmd")
    args = "/c ping -n 3 127.0.0.1 && net stop salt-minion && net start salt-minion"
    return __salt__["task.create_task"](
        name="restart-salt-minion",
        user_name="System",
        force=True,
        action_type="Execute",
        cmd=cmd,
        arguments=args,
        trigger_type="Once",
        start_date="1975-01-01",
        start_time="01:00",
    )


def execute_salt_restart_task():
    """
    Run the Windows Salt restart task

    Returns:
        bool: ``True`` if successful, otherwise ``False``

    CLI Example:

    .. code-block:: bash

        salt '*' service.execute_salt_restart_task()
    """
    return __salt__["task.run"](name="restart-salt-minion")


def status(name, *args, **kwargs):
    """
    Return the status for a service.
    If the name contains globbing, a dict mapping service name to True/False
    values is returned.

    .. versionchanged:: 2018.3.0
        The service name can now be a glob (e.g. ``salt*``)

    .. versionchanged:: 3006.0
        Returns "Not Found" if the service is not found on the system

    Args:

        name (str): The name of the service to check

    Returns:
        bool: True if running, False otherwise
        dict: Maps service name to True if running, False otherwise
        str: Not Found if the service is not found on the system

    CLI Example:

    .. code-block:: bash

        salt '*' service.status <service name>
    """

    results = {}
    all_services = get_all()
    contains_globbing = bool(re.search(r"\*|\?|\[.+\]", name))
    if contains_globbing:
        services = fnmatch.filter(all_services, name)
    else:
        services = [name]
    for service in services:
        try:
            results[service] = info(service)["Status"] in ["Running", "Stop Pending"]
        except CommandExecutionError:
            results[service] = "Not Found"
    if contains_globbing:
        return results
    return results[name]


def getsid(name):
    """
    Return the SID for this windows service

    Args:

        name (str): The name of the service for which to return the SID

    Returns:
        str: A string representing the SID for the service

    CLI Example:

    .. code-block:: bash

        salt '*' service.getsid <service name>
    """
    return info(name)["sid"]


def modify(
    name,
    bin_path=None,
    exe_args=None,
    display_name=None,
    description=None,
    service_type=None,
    start_type=None,
    start_delayed=None,
    error_control=None,
    load_order_group=None,
    dependencies=None,
    account_name=None,
    account_password=None,
    run_interactive=None,
):
    # pylint: disable=anomalous-backslash-in-string
    """
    Modify a service's parameters. Changes will not be made for parameters that
    are not passed.

    .. versionadded:: 2016.11.0

    Args:

        name (str):
            The name of the service. Can be found using the
            ``service.get_service_name`` function.

        bin_path (:obj:`str`, optional):
            The path to the service executable. Backslashes must be escaped, eg:
            ``C:\\path\\to\\binary.exe``.

            Default is ``None``.

        exe_args (:obj:`str`, optional):
            Any arguments required by the service executable.

            Default is ``None``.

        display_name (:obj:`str`, optional):
            The name to display in the service manager.

            Default is ``None``.

        description (:obj:`str`, optional):
            The description to display for the service.

            Default is ``None``.

        service_type (:obj:`str`, optional):
            Specifies the service type. ``None`` defaults to ``own``. Valid
            options are as follows:

            - kernel: Driver service
            - filesystem: File system driver service
            - adapter: Adapter driver service (reserved)
            - recognizer: Recognizer driver service (reserved)
            - own (default): Service runs in its own process
            - share: Service shares a process with one or more other services

            Default is ``None``.

        start_type (:obj:`str`, optional):
            Specifies the service start type. Valid options are as follows:

            - boot: Device driver that is loaded by the boot loader
            - system: Device driver that is started during kernel initialization
            - auto: Service that automatically starts
            - manual: Service must be started manually
            - disabled: Service cannot be started

            Default is ``None``.

        start_delayed (:obj:`bool`, optional):
            Set the service to Auto(Delayed Start). Only valid if the start_type
            is set to ``Auto``. If service_type is not passed, but the service
            is already set to ``Auto``, then the flag will be set.

            Default is ``None``.

        error_control (:obj:`str`, optional):
            The severity of the error, and action taken, if this service fails
            to start. Valid options are as follows:

            - normal: Error is logged and a message box is displayed
            - severe: Error is logged and computer attempts a restart with the
              last known good configuration
            - critical: Error is logged, computer attempts to restart with the
              last known good configuration, system halts on failure
            - ignore: Error is logged and startup continues. No notification is
              given to the user

            Default is ``None``.

        load_order_group (:obj:`str`, optional):
            The name of the load order group to which this service belongs.

            Default is ``None``.

        dependencies (:obj:`list`, optional):
            A list of services or load ordering groups that must start before
            this service.

            Default is ``None``.

        account_name (:obj:`str`, optional):
            The name of the account under which the service should run. For
            ``own`` type services this should be in the ``domain\\username``
            format. The following are examples of valid built-in service
            accounts:

            - NT Authority\\LocalService
            - NT Authority\\NetworkService
            - NT Authority\\LocalSystem
            - .\\LocalSystem

            Default is ``None``.

        account_password (:obj:`str`, optional):
            The password for the account name specified in ``account_name``. For
            the above built-in accounts, this can be None. Otherwise, a password
            must be specified.

            Default is ``None``.

        run_interactive (:obj:`bool`, optional):
            If this setting is True, the service will be allowed to interact
            with the user. Not recommended for services that run with elevated
            privileges.

            Default is ``None``.

    Returns:
        dict: a dictionary of changes made

    CLI Example:

    .. code-block:: bash

        salt '*' service.modify spooler start_type=disabled

    """
    # pylint: enable=anomalous-backslash-in-string
    # https://msdn.microsoft.com/en-us/library/windows/desktop/ms681987(v=vs.85).aspx
    # https://msdn.microsoft.com/en-us/library/windows/desktop/ms681988(v-vs.85).aspx
    handle_scm = win32service.OpenSCManager(None, None, win32service.SC_MANAGER_CONNECT)

    try:
        handle_svc = win32service.OpenService(
            handle_scm,
            name,
            win32service.SERVICE_CHANGE_CONFIG | win32service.SERVICE_QUERY_CONFIG,
        )
    except pywintypes.error as exc:
        raise CommandExecutionError(f"Failed To Open {name}: {exc.strerror}")

    config_info = win32service.QueryServiceConfig(handle_svc)

    changes = dict()

    # Input Validation
    if bin_path is not None:
        # shlex.quote the path to the binary
        bin_path = _cmd_quote(bin_path)
        if exe_args is not None:
            bin_path = f"{bin_path} {exe_args}"
        changes["BinaryPath"] = bin_path

    if service_type is not None:
        if service_type.lower() in SERVICE_TYPE:
            service_type = SERVICE_TYPE[service_type.lower()]
            if run_interactive:
                service_type = service_type | win32service.SERVICE_INTERACTIVE_PROCESS
        else:
            raise CommandExecutionError(f"Invalid Service Type: {service_type}")
    else:
        if run_interactive is True:
            service_type = config_info[0] | win32service.SERVICE_INTERACTIVE_PROCESS
        elif run_interactive is False:
            service_type = config_info[0] ^ win32service.SERVICE_INTERACTIVE_PROCESS
        else:
            service_type = win32service.SERVICE_NO_CHANGE

    if service_type is not win32service.SERVICE_NO_CHANGE:
        flags = list()
        for bit in SERVICE_TYPE:
            if isinstance(bit, int) and service_type & bit:
                flags.append(SERVICE_TYPE[bit])

        changes["ServiceType"] = flags if flags else service_type

    if start_type is not None:
        if start_type.lower() in SERVICE_START_TYPE:
            start_type = SERVICE_START_TYPE[start_type.lower()]
        else:
            raise CommandExecutionError(f"Invalid Start Type: {start_type}")
        changes["StartType"] = SERVICE_START_TYPE[start_type]
    else:
        start_type = win32service.SERVICE_NO_CHANGE

    if error_control is not None:
        if error_control.lower() in SERVICE_ERROR_CONTROL:
            error_control = SERVICE_ERROR_CONTROL[error_control.lower()]
        else:
            raise CommandExecutionError(f"Invalid Error Control: {error_control}")
        changes["ErrorControl"] = SERVICE_ERROR_CONTROL[error_control]
    else:
        error_control = win32service.SERVICE_NO_CHANGE

    if account_name is not None:
        changes["ServiceAccount"] = account_name
    if account_name in ["LocalSystem", "LocalService", "NetworkService"]:
        account_password = ""

    if account_password is not None:
        changes["ServiceAccountPassword"] = "XXX-REDACTED-XXX"

    if load_order_group is not None:
        changes["LoadOrderGroup"] = load_order_group

    if dependencies is not None:
        changes["Dependencies"] = dependencies

    if display_name is not None:
        changes["DisplayName"] = display_name

    win32service.ChangeServiceConfig(
        handle_svc,
        service_type,
        start_type,
        error_control,
        bin_path,
        load_order_group,
        0,
        dependencies,
        account_name,
        account_password,
        display_name,
    )

    if description is not None:
        win32service.ChangeServiceConfig2(
            handle_svc, win32service.SERVICE_CONFIG_DESCRIPTION, description
        )
        changes["Description"] = description

    if start_delayed is not None:
        # You can only set delayed start for services that are set to auto start
        # Start type 2 is Auto
        # Start type -1 is no change
        if (start_type == -1 and config_info[1] == 2) or start_type == 2:
            win32service.ChangeServiceConfig2(
                handle_svc,
                win32service.SERVICE_CONFIG_DELAYED_AUTO_START_INFO,
                start_delayed,
            )
            changes["StartTypeDelayed"] = start_delayed
        else:
            changes["Warning"] = 'start_delayed: Requires start_type "auto"'

    win32service.CloseServiceHandle(handle_scm)
    win32service.CloseServiceHandle(handle_svc)

    return changes


def enable(name, start_type="auto", start_delayed=False, **kwargs):
    """
    Enable the named service to start at boot

    Args:

        name (str): The name of the service to enable.

        start_type (:obj:`str`, optional):
            Specifies the service start type. Valid options are as follows:

            - boot: Device driver that is loaded by the boot loader
            - system: Device driver that is started during kernel initialization
            - auto: Service that automatically starts
            - manual: Service must be started manually
            - disabled: Service cannot be started

            Default is "auto".

        start_delayed (:obj:`bool`, optional):
            Set the service to Auto(Delayed Start). Only valid if the start_type
            is set to ``Auto``. If service_type is not passed, but the service
            is already set to ``Auto``, then the flag will be set.

            Default is ``False``.

    Returns:
        bool: ``True`` if successful, otherwise ``False``

    CLI Example:

    .. code-block:: bash

        salt '*' service.enable <service name>
    """

    modify(name, start_type=start_type, start_delayed=start_delayed)
    svcstat = info(name)
    if start_type.lower() == "auto":
        return (
            svcstat["StartType"].lower() == start_type.lower()
            and svcstat["StartTypeDelayed"] == start_delayed
        )
    else:
        return svcstat["StartType"].lower() == start_type.lower()


def disable(name, **kwargs):
    """
    Disable the named service to start at boot

    Args:

        name (str): The name of the service to disable.

    Returns:
        bool: ``True`` if disabled, otherwise ``False``

    CLI Example:

    .. code-block:: bash

        salt '*' service.disable <service name>
    """
    modify(name, start_type="Disabled")
    return info(name)["StartType"] == "Disabled"


def enabled(name, **kwargs):
    """
    Check to see if the named service is enabled to start on boot

    Args:

        name (str): The name of the service to check

    Returns:
        bool: ``True`` if the service is set to start, otherwise ``False``

    CLI Example:

    .. code-block:: bash

        salt '*' service.enabled <service name>
    """
    return info(name)["StartType"] == "Auto"


def disabled(name):
    """
    Check to see if the named service is disabled to start on boot

    Args:

        name (str): The name of the service to check

    Returns:
        bool: ``True`` if the service is disabled, otherwise ``False``

    CLI Example:

    .. code-block:: bash

        salt '*' service.disabled <service name>
    """
    return not enabled(name)


def create(
    name,
    bin_path,
    exe_args=None,
    display_name=None,
    description=None,
    service_type="own",
    start_type="manual",
    start_delayed=False,
    error_control="normal",
    load_order_group=None,
    dependencies=None,
    account_name=".\\LocalSystem",
    account_password=None,
    run_interactive=False,
    **kwargs,
):
    """
    Create the named service.

    .. versionadded:: 2015.8.0

    Args:

        name (str):
            Specifies the service name. This is not the display_name.

        bin_path (str):
            Specifies the path to the service binary file. Backslashes must be
            escaped, eg: ``C:\\path\\to\\binary.exe``.

        exe_args (:obj:`str`, optional):
            Any additional arguments required by the service binary.

            Default is ``None``.

        display_name (:obj:`str`, optional):
            The name to be displayed in the service manager. If not passed, the
            ``name`` will be used.

            Default is ``None``.

        description (:obj:`str`, optional): A description of the service.

            Default is ``None``.

        service_type (:obj:`str`, optional):
            Specifies the service type. Valid options are as follows:

            - kernel: Driver service
            - filesystem: File system driver service
            - adapter: Adapter driver service (reserved)
            - recognizer: Recognizer driver service (reserved)
            - own (default): Service runs in its own process
            - share: Service shares a process with one or more other services

            Default is "own".

        start_type (:obj:`str`, optional):
            Specifies the service start type. Valid options are as follows:

            - boot: Device driver that is loaded by the bootloader
            - system: Device driver that is started during kernel initialization
            - auto: Service that automatically starts
            - manual (default): Service must be started manually
            - disabled: Service cannot be started

            Default is "manual".

        start_delayed (:obj:`bool`, optional):
            Set the service to Auto(Delayed Start). Only valid if the start_type
            is set to ``Auto``. If service_type is not passed, but the service
            is already set to ``Auto``, then the flag will be set.

             Default is ``False``.

        error_control (:obj:`str`, optional):
            The severity of the error, and action taken, if this service fails
            to start. Valid options are as follows:

            - normal (default): Error is logged and a message box is displayed
            - severe: Error is logged and computer attempts a restart with the
              last known good configuration
            - critical: Error is logged, computer attempts to restart with the
              last known good configuration, system halts on failure
            - ignore: Error is logged and startup continues, no notification is
              given to the user

              Default is "normal".

        load_order_group (:obj:`str`, optional):
            The name of the load order group to which this service belongs.

            Default is ``None``.

        dependencies (:obj:`list`, optional):
            A list of services or load ordering groups that must start before
            this service.

            Default is ``None``.

        account_name (:obj:`str`, optional):
            The name of the account under which the service should run. For
            ``own`` type services this should be in the ``domain\\username``
            format. The following are examples of valid built-in service
            accounts:

            - NT Authority\\LocalService
            - NT Authority\\NetworkService
            - NT Authority\\LocalSystem
            - .\\LocalSystem

            Default is ``\\LocalSystem``.

        account_password (:obj:`str`, optional):
            The password for the account name specified in ``account_name``. For
            the above built-in accounts, this can be None. Otherwise, a password
            must be specified.

            Default is ``None``.

        run_interactive (:obj:`bool`, optional):
            If this setting is ``True``, the service will be allowed to interact
            with the user. Not recommended for services that run with elevated
            privileges.

            Default is ``False``.

    Returns:
        dict: A dictionary containing information about the new service

    CLI Example:

    .. code-block:: bash

        salt '*' service.create <service name> <path to exe> display_name='<display name>'
    """
    if display_name is None:
        display_name = name

    # Test if the service already exists
    if name in get_all():
        raise CommandExecutionError(f"Service Already Exists: {name}")

    # shlex.quote the path to the binary
    bin_path = _cmd_quote(bin_path)
    if exe_args is not None:
        bin_path = f"{bin_path} {exe_args}"

    if service_type.lower() in SERVICE_TYPE:
        service_type = SERVICE_TYPE[service_type.lower()]
        if run_interactive:
            service_type = service_type | win32service.SERVICE_INTERACTIVE_PROCESS
    else:
        raise CommandExecutionError(f"Invalid Service Type: {service_type}")

    if start_type.lower() in SERVICE_START_TYPE:
        start_type = SERVICE_START_TYPE[start_type.lower()]
    else:
        raise CommandExecutionError(f"Invalid Start Type: {start_type}")

    if error_control.lower() in SERVICE_ERROR_CONTROL:
        error_control = SERVICE_ERROR_CONTROL[error_control.lower()]
    else:
        raise CommandExecutionError(f"Invalid Error Control: {error_control}")

    if start_delayed:
        if start_type != 2:
            raise CommandExecutionError(
                'Invalid Parameter: start_delayed requires start_type "auto"'
            )

    if account_name in [
        "LocalSystem",
        ".\\LocalSystem",
        "LocalService",
        ".\\LocalService",
        "NetworkService",
        ".\\NetworkService",
    ]:
        account_password = ""

    # Connect to Service Control Manager
    handle_scm = win32service.OpenSCManager(
        None, None, win32service.SC_MANAGER_ALL_ACCESS
    )

    # Create the service
    handle_svc = win32service.CreateService(
        handle_scm,
        name,
        display_name,
        win32service.SERVICE_ALL_ACCESS,
        service_type,
        start_type,
        error_control,
        bin_path,
        load_order_group,
        0,
        dependencies,
        account_name,
        account_password,
    )

    if description is not None:
        win32service.ChangeServiceConfig2(
            handle_svc, win32service.SERVICE_CONFIG_DESCRIPTION, description
        )

    if start_delayed is not None:
        # You can only set delayed start for services that are set to auto start
        # Start type 2 is Auto
        if start_type == 2:
            win32service.ChangeServiceConfig2(
                handle_svc,
                win32service.SERVICE_CONFIG_DELAYED_AUTO_START_INFO,
                start_delayed,
            )

    win32service.CloseServiceHandle(handle_scm)
    win32service.CloseServiceHandle(handle_svc)

    return info(name)


def delete(name, timeout=90):
    """
    Delete the named service

    Args:

        name (str): The name of the service to delete

        timeout (:obj:`int`, optional):
            The time in seconds to wait for the service to be deleted before
            returning. This is necessary because a service must be stopped
            before it can be deleted.

            .. versionadded:: 2017.7.9,2018.3.4

            Default is 90 seconds.

    Returns:
        bool: ``True`` if successful, otherwise ``False``. Also returns ``True``
            if the service is not present

    CLI Example:

    .. code-block:: bash

        salt '*' service.delete <service name>
    """
    handle_scm = win32service.OpenSCManager(None, None, win32service.SC_MANAGER_CONNECT)

    try:
        handle_svc = win32service.OpenService(
            handle_scm, name, win32service.SERVICE_ALL_ACCESS
        )
    except pywintypes.error as exc:
        win32service.CloseServiceHandle(handle_scm)
        if exc.winerror != 1060:
            raise CommandExecutionError(f"Failed to open {name}. {exc.strerror}")
        log.debug('Service "%s" is not present', name)
        return True

    try:
        win32service.DeleteService(handle_svc)
    except pywintypes.error as exc:
        raise CommandExecutionError(f"Failed to delete {name}. {exc.strerror}")
    finally:
        log.debug("Cleaning up")
        win32service.CloseServiceHandle(handle_scm)
        win32service.CloseServiceHandle(handle_svc)

    end_time = time.time() + int(timeout)
    while name in get_all() and time.time() < end_time:
        time.sleep(1)

    return name not in get_all()
